<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+

/**
* Direct access url page
*
* Provides email/search engine friendly url access to certain modules
* 
*
* @package Misc
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: direct.php,v 1.14 2006/03/24 00:33:49 glendavies Exp $
* 
*/

/**
* Include main configuration file
*/
require_once('local/config.inc.php');

//Used by admin/setup to test operation:
if (substr($_SERVER['REQUEST_URI'],-10)=="testDirect") {
	header("HTTP/1.0 200"); echo "TEST OK!"; exit;
}


//BREAK UP THE URL PATH USING '/' as delimiter
if(isset($_GET['m'])) {   //  ?m=... access
	$url_array=explode("/",$_GET['m']);array_unshift($url_array,'','');
} else {
	//  direct[.php]/... access
	$url_array=explode("/",str_replace($CONFIG['PATH'],"",$_SERVER['REQUEST_URI']));
	
	//  404 redirect to direct access
	if(substr($url_array[1],0,6)!='direct') {array_unshift($url_array,'');}
	if(substr($url_array[1],0,14)=='direct.php?404') {		
		array_shift($url_array);
		array_shift($url_array);
	}
}

//extract the module we are dealing from the url_array
$module=$url_array[2];	  

switch($module) {
	case 'prompt':
		redirect_auto_prompt($url_array,$CONFIG['FULL_URL']);
		break;
	
	case 'post':
		redirect_post($url_array,$CONFIG['FULL_URL']);
		break;

	case 'space':
		redirect_space($url_array,$CONFIG['FULL_URL']);
		break;

	case 'kb':
		redirect_kb($url_array,$CONFIG['FULL_URL']);
		break;
				
	case 'viewf':
		$_GET['path']=substr($_SERVER['REQUEST_URI'],strpos($_SERVER['REQUEST_URI'],'viewf')+6);
		require('viewfile.php');
		break;
	
	default:
		if($module!="module") array_unshift($url_array,"");
		redirect_module($url_array,$CONFIG['FULL_URL'],$CONN);
		break;
}
exit; 

/**
* Display Error
*
* Displays an error message if the url access can't be interpreted
* 
* @author Glen Davies <glen.davies@cce.ac.nz>
* 
*/
function display_error($message) {


	global $CONFIG, $objSkins;
	
	require_once('includes/template.inc');
	$t = new Template($CONFIG['TEMPLATES_PATH']);  
	
	$t->set_file(array(
		'header'  => 'Header.ihtml',
		'errors'  => 'Errors.ihtml',
		'footer'  => 'Footer.ihtml'));

	if (!is_object($objSkins)) {
		if (!class_exists('InteractSkins')) {
			require_once($CONFIG['BASE_PATH'].'/skins/lib.inc.php');
		}
		$objSkins = new InteractSkins();
	}
	$t->set_var('SKIN_KEY',$objSkins->getSkinKey($space_key));
	$t->set_var('PATH',$CONFIG['PATH']);
	$t->set_var('SERVER_NAME',$CONFIG['SERVER_NAME']);
	
	$t->set_var('MESSAGE',$message);
	$t->set_var('PAGE_TITLE','No such Page!');
	$t->parse('CONTENTS', 'header', true); 
	$t->parse('CONTENTS', 'errors', true);
	$t->parse('CONTENTS', 'footer', true); 
	print_headers();
	//output page
	$t->p('CONTENTS');

}

/**
* Redirect to autoprompt page
*
* Gets postkey from url_array, retrieves post information and redirects
* to prompt response page 
*
* @param $url_array request url broken into section
* @author Glen Davies <glen.davies@cce.ac.nz>
* 
*/
function redirect_auto_prompt($url_array,$FULL_URL) {
	header("Location: $FULL_URL/modules/forum/autoprompt/promptaction.php?post_key={$url_array[3]}");
} //end redirect_prompt 


/**
* Redirect to a thread page to view post
*
* Gets postkey and space key from url_array, retrieves post information and redirects
* to thread view page 
*
* @param $url_array request url broken into section
* @author Glen Davies <glen.davies@cce.ac.nz>
* 
*/
function redirect_post($url_array,$FULL_URL) {

	global $CONN, $CONFIG;
	$space_key = $url_array[3];
	$post_key = $url_array[4];
	

	$rs = $CONN->Execute("SELECT {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey, {$CONFIG['DB_PREFIX']}posts.thread_key FROM {$CONFIG['DB_PREFIX']}ModuleSpaceLinks,{$CONFIG['DB_PREFIX']}posts WHERE {$CONFIG['DB_PREFIX']}posts.module_key={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey AND  {$CONFIG['DB_PREFIX']}posts.post_key='$post_key'");	

	echo $CONN->ErrorMsg();
	if ($rs->EOF) {
	
		$message = 'The post you are trying to access no longer exists - it has probably been deleted';
		display_error($message);
	
	} else {
		while (!$rs->EOF) {
	
			$module_key  = $rs->fields[0];
			$thread_key = $rs->fields[1];
			$rs->MoveNext();
		
		}
	}
		
	header("Location: {$CONFIG['FULL_URL']}/modules/forum/viewpost.php?space_key=$space_key&module_key=$module_key&post_key=$post_key");
	
} //end redirect_post 



function redirect_space($url_array,$FULL_URL) {

	global $CONN, $CONFIG;
	$space_key = $url_array[3];

	header("Location: {$CONFIG['FULL_URL']}/spaces/space.php?space_key=$space_key");
	
} //end redirect_space 



function redirect_kb($url_array,$FULL_URL) {
	global $CONN, $CONFIG;

	$space_key = $url_array[3];
	$module_key = $url_array[4];
	$entry_key = $url_array[5];
	header("Location: {$CONFIG['FULL_URL']}/modules/kb/singleentry.php?space_key=$space_key&module_key=$module_key&entry_key=$entry_key");

} //end redirect_kb 



/**
* Redirect to a space 
*
* Gets module_key, space_key, link_key from url_array, and redirects
* to module page 
*
* @param $url_array request url broken into sections
* @author Glen Davies <glen.davies@cce.ac.nz>
* 
*/
function redirect_module($url_array,$FULL_URL,$CONN) {
	global $CONFIG,$general_strings;
	
	if (!isset($url_array[4]) || $url_array[4]=='') {
	
		//must be a space the are wanting to access rather than a module
		
		$code = $CONN->qstr(str_replace("/","",$url_array[3]));
		$rs = $CONN->Execute("SELECT SpaceKey FROM {$CONFIG['DB_PREFIX']}Spaces WHERE Code=$code");
		if ($rs->EOF) {
			$message = 'Sorry. The '.$general_strings['space_text'].' you are trying to access doesn\'t seem to exist. Perhaps it has been deleted. Contact the page owner to find out.';
			display_error($message);
		
		} else {
			while (!$rs->EOF) {
				$space_key     = $rs->fields[0];
				$rs->MoveNext();
			
			}
			$rs->Close();
			header("Location: {$CONFIG['FULL_URL']}/spaces/space.php?space_key=$space_key");
		}	
		
	} else {
		$space_key = $url_array[3];
		$module_key = $url_array[4];
		
		$rs = $CONN->Execute("SELECT {$CONFIG['DB_PREFIX']}ModuleTypes.Code,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.LinkKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey FROM {$CONFIG['DB_PREFIX']}Modules,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks,{$CONFIG['DB_PREFIX']}ModuleTypes WHERE {$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey AND {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey AND {$CONFIG['DB_PREFIX']}Modules.ModuleKey='$module_key' AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key'");
		if ($rs->EOF) {
	
			$message = 'Sorry. The page you are trying to access doesn\'t seem to exist. Perhaps it has been deleted. Contact the page owner to find out.';
			display_error($message);
		
		} else {
	
			while (!$rs->EOF) {
		
				$code	  = $rs->fields[0];
				$link_key  = $rs->fields[1];
				$group_key = $rs->fields[2];
			
				$rs->MoveNext();
			
			}
		
			$rs->Close();
									
			header("Location: $FULL_URL/modules/$code/$code.php?space_key=$space_key&module_key=$module_key&link_key=$link_key&group_key=$group_key");
		
		}
	}	
} //end redirect_module
?>