<?php
// +----------------------------------------------------------------------+
// | Copyright (c) 2001 Christchurch College of Education	              |
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* Email functions
*
* Contains any functions related to sending email from interact
*
* @package Email
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: email.inc.php,v 1.19 2005/09/22 02:49:27 glendavies Exp $
* 
*/

/**
* Email users
*
* Emails a list of users 
*
* @package Email
* @param string $subject Subject of email being sent
* @param string $body Body of email being sent
* @param array $member_keys array of user keys to send email to
* @param string $copy_self true if sender wants copy
* @param string $attachment file attachment
* @param string $carbon_copy comma separated string of email addresses to copy to
*/
function email_users($subject, $body, $member_keys, $copyself='', $attachment='', $carbon_copy='',$from='') {

    global $CONN, $CONFIG;
	
	require_once($CONFIG['INCLUDES_PATH'].'/pear/Mail.php');
	
    $error_messages = ''; 
    
	if ($CONFIG['EMAIL_TYPE']=='sendmail') {
	
	    $params['sendmail_path'] = $CONFIG['EMAIL_SENDMAIL_PATH'];
		$params['sendmail_args'] = $CONFIG['EMAIL_SENDMAIL_ARGS'];
 		
	} else if ($CONFIG['EMAIL_TYPE']=='smtp') {
	
	    $params['host']     = $CONFIG['EMAIL_HOST']; 
        $params['port']     = $CONFIG['EMAIL_PORT'] ; 
        $params['auth']     = $CONFIG['EMAIL_AUTH'];  
        $params['username'] = $CONFIG['EMAIL_USERNAME']; 
        $params['password'] = $CONFIG['EMAIL_PASSWORD'];
		
		
	}
   	
    require_once($CONFIG['INCLUDES_PATH'].'/pear/Mail/mime.php');
	$mime = new Mail_mime("\n");

	if ($attachment['name']!='') {
	
        $mime->setTXTBody(strip_tags($body));
		if (!eregi('(<p|<br)', $body)) {
			
			$html_body = nl2br($body);
		
   		} else {
		
			$html_body = $body;
		
		}
		$mime->setHTMLBody(strip_tags($html_body,"<a>,<i>,<b>,<p>,<font>,<br />,<h1>,<h2>,<h3>,<h4>,<h5>,<h6>,<table>,<tr>,<td>,<ul>,<ol>,<li>,<strong>,<em>,<sup>,<sub>,<br />,<blockquote,<span>,<div>"));
        
		$mime->addAttachment($attachment['tmp_name'], 'application/octet-stream',$attachment['name']);

        $body_txt = $mime->get();
        $headers = $mime->headers($headers);
		
	} else {
	
	    $mime->setTXTBody(strip_tags($body));
		if (!eregi('(<p|<br)', $body)) {
			
			$html_body = nl2br($body);
		
   		} else {
		
			$html_body = $body;
		
		}
        $mime->setHTMLBody(strip_tags($html_body,"<a>,<i>,<b>,<p>,<font>,<h1>,<h2>,<h3>,<h4>,<h5>,<h6>,<table>,<tr>,<td>,<ul>,<ol>,<li>,<strong>,<em>,<sup>,<sub>,<br>,<blockquote>,<span>,<div>"));
		$body_txt = $mime->get();
        $headers = $mime->headers($headers);
		
	}

    if (!isset($from) || $from=='') {
		if (isset($_SESSION['current_user_email'])) {
		$headers['From']    = '"'.$_SESSION['current_user_firstname'].' '.$_SESSION['current_user_lastname'].'" <'.$_SESSION['current_user_email'].'>';
		} else {
			$headers['From']    = '"No Reply" <'.$CONFIG['NO_REPLY_EMAIL'].'>';
		}
	} else {
		$headers['From']    = '"No reply" <'.$from.'>';
	}
    $headers['Subject'] = $subject;
	
    $mail_object =& Mail::factory($CONFIG['EMAIL_TYPE'], $params);
    if (!method_exists($mail_object,'send')) {print 'mail error: '.$mail_object->getMessage()."<br />\n";exit;}

	$recipients = '';

	if (is_array($member_keys)) {
	
	    foreach ($member_keys as $value) {
	
	        $sql = "SELECT FirstName, LastName, Email FROM {$CONFIG['DB_PREFIX']}Users WHERE UserKey='$value'";
  
            $rs = $CONN->Execute($sql);
    
	        while (!$rs->EOF) {
                    
                $first_name=$rs->fields[0];
                $last_name=$rs->fields[1];
                $email=$rs->fields[2];
                $full_email='"'.$first_name.' '.$last_name.'" <'.$email.'>';
		        $to = $email;
			    $recipients .= $to."\n";

                $headers['To'] = $full_email;
                $result = $mail_object->send($to, $headers, $body_txt);
    
	            if (PEAR::isError($result)) {
    
	                $error_messages .= 'mail error for : '.$full_email.' '.$result->getMessage()."<br />\n";
    
	            } 
		    
			    $rs->MoveNext();
		
	        }
		
	    }
		
	} else {
	
	    $sql = "SELECT FirstName, LastName, Email FROM {$CONFIG['DB_PREFIX']}Users WHERE UserKey='$member_keys'";
  
        $rs = $CONN->Execute($sql);
    
	    while (!$rs->EOF) {
                    
            $first_name=$rs->fields[0];
            $last_name=$rs->fields[1];
            $email=$rs->fields[2];
            $full_email='"'.$first_name.' '.$last_name.'" <'.$email.'>';
		    $to = $email;
		    $recipients .= $to."\n";

            $headers['To'] = $full_email;
			$result = $mail_object->send($to, $headers, $body_txt);

	        if (PEAR::isError($result)) {
    
				$error_messages .= 'mail error for : '.$full_email.' '.$result->getMessage()."<br />\n";
    
	        } 
		    
			$rs->MoveNext();
		
	    }	
	
	}
	
	if ($carbon_copy) {
	
        $carbon_copy_array=explode(',',$carbon_copy);
        foreach ($carbon_copy_array as $to) {
        
		    $to=trim($to);
            $headers['To'] = $to;
			$recipients .= $to."\n";
            $result = $mail_object->send($to, $headers, $body_txt);
    
	        if (PEAR::isError($result)) {
    
	            $error_messages .= 'mail error for : '.$to.' '.$result->getMessage()."<br />\n";
    
	        } 
			
		}
		
	}
	
    if ($copyself=='true') {
  
        $body .= "\n\nThis email was sent to: \n".$recipients;
		$headers['Subject'] = $subject;
 	
	    if ($attachment['name']!='') {
            
        	$mime->setTXTBody(strip_tags($body));
			if (!eregi('(<p|<br)', $body)) {
			
				$html_body = nl2br($body);
		
   			} else {
		
				$html_body = $body;
		
			}

        	$mime->setHTMLBody(strip_tags($html_body,"<a>,<i>,<b>,<p>,<font>,<br>,<h1>,<h2>,<h3>,<h4>,<h5>,<h6>,<table>,<tr>,<td>,<ul>,<ol>,<li>,<strong>,<em>,<sup>,<sub>,<blockquote>,<span>,<div>"));
        
			//$mime->addAttachment($attachment['tmp_name'], 'application/octet-stream',$attachment['name']);

        	$body_txt = $mime->get();
        	$headers = $mime->headers($headers);
					
		} else {
		
	    	$mime->setTXTBody(strip_tags($body));
			if (!eregi('(<p|<br)', $body)) {
			
				$html_body = nl2br($body);
		
   			} 

        	$mime->setHTMLBody(strip_tags($html_body,"<a>,<i>,<b>,<p>,<font>,<br>,<h1>,<h2>,<h3>,<h4>,<h5>,<h6>,<table>,<tr>,<td>,<ul>,<ol>,<li>,<strong>,<em>,<sup>,<sub>,,<blockquote>,<span>,<div>"));
			$body_txt = $mime->get();
        	$headers = $mime->headers($headers);
			
		}

		$to = $_SESSION['current_user_email'];
		$headers['To'] = $headers['From'];
		$result = $mail_object->send($to, $headers, $body_txt);
    
	    if (PEAR::isError($result)) {
    
	        $error_messages .= 'mail error for : '.$to.' '.$result->getMessage()."<br />\n";
    
	    } 
		
	}
	
	if ($error_messages=='') {
		return true;
	} else {
		echo "Your email has been sent, but the following problems were reported.<br/>".$error_messages;
	}					
					
      
}

?>