<?php
// +----------------------------------------------------------------------+
// | Copyright (c) 2001 Christchurch College of Education				  |
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* HTML functions
*
* Contains any html related functions
*
* @package Common
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: html.inc.php,v 1.31 2005/12/21 00:25:38 glendavies Exp $
* 
*/

/**
* A class that contains methods related to html functions 
* 
* 
* This class is part of the Interact online learning and collaboration platform. 
* It contains methods simple html functions, creating menus, tables, etc. 
* 
* @package Common
* @author Glen Davies <glen.davies@cce.ac.nz>
*/
class InteractHtml {

	/**
	* Create a select menu from an array  
	* 
	* @param array $array array to create menu from
	* @param string $name name of menu
	* @param string/array $selected items to be shown as selected in menu
	* @param string $multiple true if multiple selection allowed
	* @param string $size size of menu
	* @return $menu html code for menu
	*/

	function arrayToMenu($array, $name, $selected='', $multiple=false, $size='', $blank=false, $javascript='')
	{

		$menu =  '<select '.$javascript.' name="'.$name.'" id="'.$name.'"';
		
		if ($multiple===true) {
		
			$menu .= 'multiple ';
			
		} 
		
		if ($size!='') {
		
		
			$menu .= 'size="'.$size.'"';
			
		}
		 
		$menu .= '>'; 
		
		if ($blank==true) {
		 
			 $menu .= '<option value="" selected>-----</option>';
			 
		}
		
		foreach ($array as $key => $value) {
		
			if (is_array($selected)) {
			
				if (in_array($key, $selected)) {
				
				
					$menu .= '<option value="'.$key.'" selected>'.$value.'</option>';
					
				} else {
				
					$menu .= '<option value="'.$key.'">'.$value.'</option>';
					
				}
				
			} else {
			
				if ($key==$selected) {
				
				
					$menu .= '<option value="'.$key.'" selected>'.$value.'</option>';
					
				} else {
				
					$menu .= '<option value="'.$key.'">'.$value.'</option>';
					
				}
				
			}
			
		}
						
		$menu .= '</select>'; 
	
		return $menu;
	
	} //end arrayToMenu

	/**
	* Add required javascript to template for running editor  
	* 
	* @param object $t template object
	* @param int $auto_editor 1 if editor to auto load
	* @param string $form_field field id to load editor in
	* @return true
	*/

	function setTextEditor(&$t, $auto_editor, $form_field='', $full_page=false)
	{

		 global $CONFIG, $general_strings;
		 
		 $browser=browser_get_agent();
		 if (($browser['agent']=='IE' && $browser['version']>=5.5 && $browser['platform']=='Win') || $browser['gecko_version']>='20030210') {
						   
			if (!($t->get_var('EDITOR_JAVASCRIPT'))) {
				$t->set_var('EDITOR_JAVASCRIPT','<script type="text/javascript">
							   _editor_url = "'.$CONFIG['PATH'].'/includes/editor/";
							   _editor_lang = "en";
							   full_page='.($full_page? 'true' : 'false').'
							   </script>
							   <script type="text/javascript" src="'.$CONFIG['PATH'].'/includes/editor/htmlarea.js"></script>
<script type="text/javascript" src="'.$CONFIG['PATH'].'/includes/editor.js"></script>');
			}
			
			if ($auto_editor && $form_field) {
		
				$t->set_var('SCRIPT','onload="initEditor(\''.$form_field.'\')"');
				$t->set_var('EDITOR_BUTTONS_'.$form_field,'');
				
			} else {
				$t->set_var('EDITOR_BUTTONS_'.$form_field,'<div align="center"><input type="button" name="Button" value="'.$general_strings['easy_edit'].'" class="small" onClick="runSingleEditor(\''.$form_field.'\', \'button_for_'.$form_field.'\')" id=\'button_for_'.$form_field.'\'></div>');
		
				$t->set_var('SCRIPT','');
			}
			
		} else {
			$t->set_var('EDITOR_BUTTONS_'.$form_field,'<div align="center"><input type="button" name="link" value="'.$general_strings['insert_link'].'" class="small" onClick="make_link(\''.$form_field.'\')"/>
<input type="button" name="elink" value="'.$general_strings['email_link'].'" class="small" onClick="make_email_link(\''.$form_field.'\')" /> 
<input type="button" value="'.$general_strings['preview'].'" name="preview" class="small" onClick="display_html(\''.$form_field.'\')"/> 
<input type="button" name="Italics" value="'.$general_strings['italic_abb'].'" class="small" style="font-style:italic" onClick="make_italics(\''.$form_field.'\')" /> 
<input type="button" name="Bols" value="'.$general_strings['bold_abb'].'" class="small" style="font-weight:bold" onClick="make_bold(\''.$form_field.'\')"/> ');

			$t->set_var('EDITOR_BUTTONS_'.$form_field,'<input type="button" name="image" value="'.$general_strings['add_image'].'" class="small" onClick="evalfunction=\'make_image(\\\''.$form_field.'\\\',param)\';get_image(\''.$CONFIG['PATH'].'\');document.getElementById(\''.$form_field.'\').focus();" />',true);

			if (!($t->get_var('EDITOR_JAVASCRIPT'))) {
				$t->set_var('EDITOR_JAVASCRIPT','<script type="text/javascript" language="javascript"  src="'.$CONFIG['PATH'].'/includes/editor/dialog.js" ></script><script type="text/javascript" language="javascript"  src="'.$CONFIG['PATH'].'/includes/editor/use_dialogs.js" ></script>');
			}
			$t->set_var('EDITOR_BUTTONS_'.$form_field,'</div>',true);
			$t->set_var('SCRIPT','');
		}
		return true;
	
	} //end setTextEditor


	/**
	* Parse text to replace any video and sound placeholders, turn links to html, etc.  
	* 
	* @param string $text text to convert links in
	* @return string $parsed_text
	*/
	function parseText($text) {
	
	
		$parsed_text = $this->urlsToLinks($text);
		
		//if no paragraph or break tags replace \n with <br />
		
		if (!eregi('(<p|<br)', $parsed_text)) {
			
			$parsed_text = nl2br($parsed_text);
		
   		} 
		
		$parsed_text = $this->replaceMediaPlaceholders($parsed_text);
		$parsed_text = $this->replaceUserVariables($parsed_text);
		$parsed_text = $this->textoGif($parsed_text);
		//$parsed_text = $this->popupLinks($parsed_text);
		 		
		return $parsed_text;
	
	}
	
	/**
	* Convert links in a string to html  
	* 
	* @param string $text text to convert links in
	* @return string $linked_text
	*/
	function urlsToLinks($text) {
	
		// Make long URLs into links
		// Regexp improved by Bruce.
		$linked_text = eregi_replace("([[:space:].,\(\[])([[:alnum:]]{3,})://([[:alnum:]_-]+\.)([[:alnum:]_-]{2,}[[:alnum:]/&=#?_\.-]*)",
						  "\\1<a href=\"\\2://\\3\\4\" target=\"newpage\">\\2://\\3\\4</a>", $text);

	   // Make short urls into links
		$linked_text = eregi_replace("([[:space:],\(\[])www\.([[:alnum:]_-]+\.)([[:alnum:]_-]{2,}[[:alnum:]/&=#?_\.-]*)", "\\1<a href=\"http://www.\\2\\3\" target=\"newpage\">www.\\2\\3</a>", $linked_text);
						  
		return $linked_text;
						  
			
	}//end urlsToLinks()
	
	/**
	* Replace media place holders with flash objects  
	* 
	* @param string $text text to replace placeholders in
	* @return string $text
	*/
	function replaceMediaPlaceholders($text) {
	
		global $CONFIG;
		
		$text = preg_replace("/<img[^>]*XX([^X]*)XXfixed:([^:]*):([^:]*):([^\"]*)XX[^X]*XX\"[^>]*\>/i", "<object classid=\"clsid:d27cdb6e-ae6d-11cf-96b8-444553540000\" codebase=\"http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,0,0\" width=\"$2\" height=\"$3\" id=\"$1\" align=\"middle\">
<param name=\"allowScriptAccess\" value=\"sameDomain\" />
<param name=\"movie\" value=\"{$CONFIG['FULL_URL']}/includes/players/$1.swf\" />
<param name=\"FlashVars\" value=\"$4\" />
<param name=\"quality\" value=\"high\" />
<embed src=\"{$CONFIG['FULL_URL']}/includes/players/$1.swf\" FlashVars=\"$4\" quality=\"high\"  width=\"$2\" height=\"$3\" name=\"checkpoint\" align=\"middle\" allowScriptAccess=\"sameDomain\" type=\"application/x-shockwave-flash\" pluginspage=\"http://www.macromedia.com/go/getflashplayer\" />
</object>", $text);
						  
		return $text;
						  
			
	}//end urlsToLinks()	
	
	/**
	* Replace user variables  
	* 
	* @param string $text text to replace user variables in
	* @return string $text
	*/
	function replaceUserVariables($text) {
	
		global $CONFIG;
		
		if (isset($_SESSION['current_user_key'])) {
		
			$text = str_replace('[first_name]', $_SESSION['current_user_firstname'], $text);
			$text = str_replace('[last_name]', $_SESSION['current_user_lastname'], $text);
			
		} else {
		
			$text = str_replace('[first_name]', '', $text);
			$text = str_replace('[last_name]', '', $text);
		
		}
						 
		return $text;
						  
			
	}//end replaceUserVariables()	

	/**
	* Replace tex forumla  
	* 
	* @param string $text text to replace user variables in
	* @return string $text
	*/
	
	function textoGif($text) 
	{
    
	
	preg_match_all('/\[EQ(.+?)EQ\]|\$\$(.+?)\$\$/is', $text, $matches);  
    for ($i=0; $i<count($matches[0]); $i++) {
        $texexp = $matches[1][$i] . $matches[2][$i];
		$texexp = str_replace('<br />','',$texexp);
		$texexp = str_replace('<br />','',$texexp);
		//$texexp = urlencode($texexp);
        $text = str_replace( $matches[0][$i],  "<img src=\"/cgi-bin/mimetex.cgi?$texexp\">", $text);
    }

	return $text; 
	
	
	}
	
	/**
	* Replace popup links  
	* 
	* @param string $text text to replace popup links
	* @return string $text
	*/
	/*
	function popupLinks($text) 
	{
    
	$text = preg_replace('/\[POPUP:([^:]*):([^:]*):([^:]*):([^\]]*)\]/i', "<span class=\"vlink\" onClick=\"window.open ('$2', '30', 'toolbar=no, scrollbars=yes, width=$3, height=$4, menubar=no, location=no, resizable=yes')\">$1</span>",$text);
	//'/\[POPUP:([^:]*):([^:]*):([^:]*):([^\]]*)\]/i'
	//preg_match_all('/\[POPUP([^X]*)\]/i', $text, $matches);  
    //for ($i=0; $i<count($matches[0]); $i++) {
         
    	//$parts = explode(':',$matches[1][$i]);
        //$text = str_replace( $matches[0][$i],  "<span class=\"vlink\" onClick=\"window.open ('".$parts[2]."', '30', 'toolbar=no, scrollbars=yes, width=".$parts[3].", height=".$parts[4].", menubar=no, location=no, resizable=yes')\">".$parts[1]."</span>", $text);
    //}

	return $text; 
	
	
	}
	*/
	/**
	* Generate an icon tag for non-standard icons  
	* 
	* @param int $icon_key key of icon 
	* @param string $type small or large
	* @return string $icon_tag icon tag string
	*/
	function getIconTag($icon_key, $type='small') {
	
  		global $CONN, $CONFIG;
		
		if ($type=='small') {
			$field = 'SmallIcon';
		} else {
			$field = 'LargeIcon';
		}
		$rs = $CONN->Execute("SELECT $field FROM {$CONFIG['DB_PREFIX']}Icons WHERE IconKey='$icon_key'");
		
		while (!$rs->EOF) {
			$icon = $rs->fields[0];		
			$rs->MoveNext();			
		} 
		$rs->Close();
		
		if (is_file($CONFIG['BASE_PATH'].'/local/modules/icons/'.$icon)) {
			
			$icon = '<img class="icon" src="'.$CONFIG['MODULE_FILE_VIEW_PATH'].'icons/'.$icon.'">';
			return $icon;	
		} else {
			return false;
		}
			
	}//end getIconTag()
	
	/**
	* Generate an icon url for non-standard icons  
	* 
	* @param int $icon_key key of icon 
	* @param string $type small or large
	* @return string $icon_url icon tag string
	*/
	function getIconUrl($icon_key, $type='small') {
	
  		global $CONN, $CONFIG;
		
		if ($type=='small') {
		
			$field = 'SmallIcon';
		
		} else {
		
			$field = 'LargeIcon';
		
		}
		$rs = $CONN->Execute("SELECT $field FROM {$CONFIG['DB_PREFIX']}Icons WHERE IconKey='$icon_key'");
				   
		while (!$rs->EOF) {
		
			$icon = $rs->fields[0];		
			$rs->MoveNext();			
		
		} 
		
		$rs->Close();
		
		if (is_file($CONFIG['MODULE_FILE_SAVE_PATH'].'/icons/'.$icon)) {
		

			$icon_url = $CONFIG['MODULE_FILE_VIEW_PATH'].'icons/'.$icon;
			return $icon_url;
				
		
		} else {
		
			return false;
		
		}
			
	}//end getIconUrl()	

} //end InteractHtml
?>