<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+

/**
* Comment input
*
* Input a new comment in a module that allows comments
*
* @package Modules
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2001 
* @version $Id: commentinput.php,v 1.7 2006/03/03 04:37:01 websterb4 Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../../local/config.inc.php');
session_start();

	
$space_key 	= get_space_key();

if ($_SERVER['REQUEST_METHOD']=='GET') {
	foreach($_GET as $key => $value) {
		$post_data[$key] = $value;
 	}
 	$module_key = $_GET['module_key'];
 	$space_key  = $_GET['space_key'];
 	$action     = isset($_GET['action']) ? $_GET['action'] : '';	
} else if($_SERVER['REQUEST_METHOD']=='POST'){
 	foreach($_POST as $key => $value) {
		$post_data[$key] = $value;
 	}	
	$module_key = $_POST['module_key'];
	$space_key  = $_POST['space_key'];	
 	$action     = isset($_POST['action']) ? $_POST['action'] : '';
}
$current_user_key=$_SESSION['current_user_key'];
$link_key 	= get_link_key($module_key,$space_key);
//check we have the required variables
check_variables(true,false,true);

//check to see if user is logged in. If not refer to Login page.
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];
$group_access = $access_levels['groups'];

if (!isset($current_user_key)) {
	$request_uri = urlencode($REQUEST_URI);
	$message = urlencode($forum_strings['login_to_post']);
	header("Location: {$CONFIG['FULL_URL']}/login.php?request_uri=$request_uri&message=$message");
	exit;
} 

if (!isset($objPosts) || !is_object($objPosts)) {
	if (!class_exists('InteractPosts')) {
		require_once('../../includes/lib/posts.inc.php');
	}
	$objPosts = new InteractPosts();
	$objPosts->setVars($module_key, $space_key);
}
// See if the form has been submitted
if($_SERVER['REQUEST_METHOD'] == 'POST') {

	switch($_POST['submit']) {
	
		case $general_strings['add']:
			$post_data['added_by_key'] = $_SESSION['current_user_key'];	
			$post_data['user_key']     = $_SESSION['current_user_key'];
			$message = $objPosts->addPost(array('module_key', 'parent_key','thread_key','body','user_key','added_by_key', 'date_added', 'subject'),$post_data);
			header('Location: '.$CONFIG['FULL_URL'].urldecode($post_data['referer']));
			exit;
		break;
		case $general_strings['modify']:
			$post_data['modifed_by_key'] = $_SESSION['current_user_key'];	
			$message = $objPosts->modifyPost(array('body','modified_by_key','date_modifed', 'subject'),$post_data);
			header('Location: '.$CONFIG['FULL_URL'].urldecode($post_data['referer']));
		break;
		case $general_strings['delete']:
			$message = $objPosts->deletePost($post_data);
			$referer = urldecode($post_data['referer']);
			header('Location: '.$CONFIG['FULL_URL'].urldecode($post_data['referer']));
		break;
	}
}
require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	"header"		  => "Header.ihtml",
	"navigation"	  => "Navigation.ihtml",
	"comments"		 => "modules/Comments.ihtml",
	"footer"		  => "Footer.ihtml"
));
// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);

set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);
if (!isset($objHtml) || !is_object($objHtml)){
	if (!class_exists('InteractHtml')) {
		require_once('../../includes/lib/html.inc.php');
	}
	$objHtml= new InteractHtml();
}
$objHtml->setTextEditor($t, $_SESSION['auto_editor'], 'body');
$t->parse('CONTENTS', 'header', true); 
get_navigation();
$t->set_var('COMMENT_INPUT_HEADING', $general_strings['reply_to_comment']);
$t->set_var('MODULE_KEY', $module_key);
$t->set_var('SPACE_KEY', $space_key);
$t->set_var('PARENT_KEY', $post_data['parent_key']);
$t->set_var('POST_KEY', $post_data['post_key']);
$t->set_var('THREAD_KEY', $post_data['thread_key']);
$t->set_var('REFERER', $post_data['referer']);
$t->set_block('comments', 'ReplyBlock', 'RepBlock');
switch($action) {
	case 'Reply':
		$t->set_block('comments', 'DeleteBlock', 'DelBlock');
		$t->set_var('ADD_COMMENT', $general_strings['reply']);
		$t->set_var('SUBMIT_BUTTON', $general_strings['add']);
		$limits = array('module_key' => $module_key, 'post_key' => $post_data['parent_key']);
		$parent_data = $objPosts->getPostData($limits,true);
		$objPosts->formatPost($parent_data);

	break;
		
	case 'Modify':
		$t->set_var('ADD_COMMENT', $general_strings['modify_comment']);
		$t->set_var('SUBMIT_BUTTON', $general_strings['modify']);
		$limits = array('module_key' => $module_key, 'post_key' => $post_data['post_key']);
		$post_data = $objPosts->getPostData($limits,true);	
		$t->set_block('comments', 'CommentBlock', 'CmmntBlock');
	break;
}					

//now set values for any undefined variables in templates
$t->set_strings('comments',  $journal_strings, $post_data[0], $errors);

$t->parse('CONTENTS', 'comments', true);
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p('CONTENTS');
$CONN->Close();	   
exit;	

?>