<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* Journal entry comment input page
*
* Displays the journal entry comment input/modify page
*
* @package Journals
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: commentinput.php,v 1.19 2006/02/12 22:37:15 websterb4 Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../../local/config.inc.php');
require_once($CONFIG['LANGUAGE_CPATH'].'/journal_strings.inc.php');
require_once('lib.inc.php');
session_start();

//set the required variables

if ($_SERVER['REQUEST_METHOD']=='GET') {

	$module_key			= $_GET['module_key'];
	$group_key			= $_GET['group_key'];
	$action 			= $_GET['action'];
	$journal_user_key 	= $_GET['journal_user_key'];
	$entry_key 			= $_GET['entry_key'];
	$comment_key 		= $_GET['comment_key'];
	$parent_key 		= $_GET['parent_key'];	
	$comment_parent_key = $_GET['comment_parent_key'];
	$quote_entry		= $_GET['quote_entry'];						
	
} else {

	$module_key			= $_POST['module_key'];
	$group_key			= $_POST['group_key'];
	$action 			= $_POST['action'];	
	$journal_user_key 	= $_POST['journal_user_key'];
	$entry_key 			= $_POST['entry_key'];		
	$comment_key 		= $_POST['comment_key'];
	$parent_key 		= $_POST['parent_key'];
	$comment_parent_key = $_POST['comment_parent_key'];
	$body				= $_POST['body'];
	$submit				= $_POST['submit'];	
	
}

$userlevel_key = $_SESSION['userlevel_key'];

$space_key 	= get_space_key();
$link_key 	= get_link_key($module_key,$space_key);

//check we have the required variables
check_variables(true,true,true);

//check to see if user is logged in. 
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];
$group_access = $access_levels['groups'];
$group_accesslevel = $access_levels['group_accesslevel'][$group_key];
$is_admin = check_module_edit_rights($module_key);

//create an InteractUser class so we can retrieve user details
if (!class_exists('InteractUser')) {

	require_once('../../includes/lib/user.inc.php');
	
}

$user = new InteractUser();
$user_data = $user->getUserData($journal_user_key);

$journal = new InteractJournal($space_key, $module_key, $group_key, $is_admin, $journal_strings);
$journal->setJournalSettings();
$journal->setJournalUserKey($journal_user_key);

//see if we are adding a new entry

if ($action) {

	switch($action) {
	
		case 'add':
		
			if ($journal->checkCommentEditRights($action,$comment_key)==true) {

				$errors = $journal->checkFormInput($body,$journal_strings);

				if (count($errors)>0) {
	
					$message = $journal_strings['input_error'];
	
				} else {
	
					$message = $journal->addComment($entry_key,$parent_key,$body);
		
					if ($message==true) {
		
						$message = urlencode($journal_strings['comment_add_success']);
						header("Location: {$CONFIG['FULL_URL']}/modules/journal/journalview.php?space_key=$space_key&module_key=$module_key&group_key=$group_key&link_key=$link_key&journal_user_key=$journal_user_key&message=$message&view_comments=$entry_key#$entry_key");
						exit;
		
					}
		
				} 
			
			} else {
			
			
			
			}
			
		break;
		
		case 'modify2':
		
			if ($submit==$journal_strings['delete_button']) {

				if ($journal->checkCommentEditRights('modify',$comment_key)==true) {

					$message = $journal->deleteComment($comment_key);
		
					if ($message===true) {
		
						$message = urlencode($journal_strings['comment_delete_success']);
						header("Location: {$CONFIG['FULL_URL']}/modules/journal/journalview.php?space_key=$space_key&module_key=$module_key&group_key=$group_key&link_key=$link_key&journal_user_key=$journal_user_key&message=$message");
						exit;
		
					} else {
					
						$message = $journal_strings['comment_delete_failure'].' - '.$message;
						
					}
							
				}			
				
			} else { 
			
				if ($journal->checkJournalEditRights('modify',$entry_key)==true) {

					$errors = $journal->checkFormInput($body,$journal_strings);

					if (count($errors)>0) {
	
						$message = $journal_strings['input_error'];
	
					} else {
	
						$message = $journal->modifyComment($comment_key,$body);
		
						if ($message===true) {
		
							$message = urlencode($journal_strings['comment_modify_success']);
							header("Location: {$CONFIG['FULL_URL']}/modules/journal/journalview.php?space_key=$space_key&module_key=$module_key&group_key=$group_key&link_key=$link_key&journal_user_key=$journal_user_key&message=$message&view_comments=$entry_key#$entry_key");
							exit;
		
						} else {
					
							$message = $journal_strings['comment_modify_failure'].' - '.$message;
						
						}
		
					} 
			
				}
				
			}
			
		break;		

	}

}
require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	"header"		  => "Header.ihtml",
	"navigation"	  => "Navigation.ihtml",
	"journal"		 => "journal/CommentInput.ihtml",
	"footer"		  => "Footer.ihtml"
));

// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);

set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);

if ($action=='add' || $action=='') {

	$heading = $journal_strings['add_comment'];   

} else if ($action=='modify' || $action=='modify2') {

	$heading = $journal_strings['modify_comment'];
	
} else if ($action=='reply' || $action=='reply_quoted') {

	$heading = $journal_strings['add_comment_reply'];

}

$t->set_var('SPACE_KEY',$space_key);
$t->set_var('HEADING',sprintf($heading,$page_details['module_name'],$user_data['first_name'].' '.$user_data['last_name']));
$t->set_var('MODULE_KEY',$module_key);
$t->set_var('GROUP_KEY',$group_key);
$t->set_var('MODULE_NAME',$page_details['module_name']);
$t->set_var('LINK_KEY',$link_key);
$t->set_var('RETURN_TO_STRING',$general_strings['return_to']);
$t->set_var('COMMENT_STRING',$general_strings['comment']);
$t->set_var('INPUT_SUGGESTION',$general_strings['text_input_suggestion']);
$t->set_var('CANCEL_STRING',$general_strings['cancel']);

$t->set_var('ACTION',$action);

//generate the editor components

if (!class_exists('InteractHtml')) {

	require_once('../../includes/lib/html.inc.php');
	
}
$html = new InteractHtml();
$html->setTextEditor($t, $_SESSION['auto_editor'], 'body');

$t->parse('CONTENTS', 'header', true); 
get_navigation();

//if user is not and admin, and journal is closed do not show input box 

if($journal->checkCommentEditRights($action,$comment_key)==false) {

	$t->set_block('journal', 'EntryInputBlock', 'EIBlock'); 

	if ($action=='add' || $action=='' || $action=='reply' || $action=='reply_quoted') {
	
		$t->set_var('EIBlock',sprintf($journal_strings['no_comment_add_rights'],$user_data['first_name'].' '.$user_data['last_name']));
		
	} else {

		$t->set_var('EIBlock',$journal_strings['no_comment_modify_rights']);	
		
	}
			
} else {

	$journal->displayCommentInputForm($action,$errors,$entry_key,$comment_key,$parent_key,$quote_entry);
	
}


$t->parse('CONTENTS', 'journal', true);
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p("CONTENTS");
$CONN->Close();	   
exit;	
?>
