<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* Journal view page
*
* Displays a journal entries page. If user is an admin, or if journal is open 
* then display requested users journal, or if not display current users journal
*
* @package Journals
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: journalview.php,v 1.29 2006/03/19 21:40:34 glendavies Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../../local/config.inc.php');
require_once($CONFIG['LANGUAGE_CPATH'].'/journal_strings.inc.php');
require_once('lib.inc.php');
session_start();

//set the required variables

if ($_SERVER['REQUEST_METHOD']=='GET') {

	$module_key			= $_GET['module_key'];
	$group_key			= $_GET['group_key'];
	$journal_user_key	= $_GET['journal_user_key'];
	$show_comments		= isset($_GET['show_comments'])? $_GET['show_comments'] : '';
	$sort_order			= isset($_GET['sort_order'])? $_GET['sort_order'] : '';
	$tag_key			= isset($_GET['tag_key']) ? $_GET['tag_key'] : '';
	$date_limit			= isset($_GET['date_limit']) ? $_GET['date_limit'] : '';	
} else {

	$show_comments		= isset($_POST['show_comments'])? $_POST['show_comments'] : '';
	$module_key			= $_POST['module_key'];
	$group_key			= $_POST['group_key'];
	$journal_user_key	= $_POST['journal_user_key'];	
	$view				= $_POST['view'];
	$sort_order			= $_POST['sort_order'];
	$tag_key			= isset($_POST['tag_key']) ? $_POST['tag_key'] : '';

}
if (isset($_POST['show_new']) && $_POST['show_new']!=0) {
	$show_new = $_POST['show_new'];
	$last_use_seconds = $_POST['show_new']*86400;
	$last_use = date('Y-m-d H:i:s',time()-$last_use_seconds);
	//if they have not logged in before set their last login to today
} else if ($_SESSION['last_use']>0) {
	$last_use = $_SESSION['last_use'];
} else {
	$last_use = date('Y-m-d H:i:s');
}	
$userlevel_key	  = $_SESSION['userlevel_key'];
$space_key 	= get_space_key();
$link_key 	= get_link_key($module_key,$space_key);

//check we have the required variables
check_variables(true,true,true);

//check to see if user is logged in. 
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];
$group_access = $access_levels['groups'];
$group_accesslevel = $access_levels['group_accesslevel'][$group_key];
$is_admin = check_module_edit_rights($module_key);

$objJournal = new InteractJournal($space_key, $module_key, $group_key, $is_admin, $journal_strings);
$objJournal->setJournalSettings();
$journal_settings = $objJournal->getJournalSettings();

//if user is not an admin, and journal is closed only show current users 
//entries

if($objJournal->checkShowAll()==false && $journal_user_key!=$_SESSION['current_user_key']) {

	$journal_user_key = $_SESSION['current_user_key']; 

}
$objJournal->setJournalUserKey($journal_user_key);
//create an InteractUser class so we can retrieve user details
if (!isset($objUser) || !is_object($objUser)){
	if (!class_exists('InteractUser')) {
		require_once('../../includes/lib/user.inc.php');
	}
	$objUser = new InteractUser();
}
$user_data = $objUser->getUserData($journal_user_key);
if (!isset($objPosts) || !is_object($objPosts)){
	if (!class_exists('InteractPosts')) {
		require_once('../../includes/lib/posts.inc.php');
	}
	$objPosts = new InteractPosts();

	$objPosts->setVars($module_key, $space_key);
	
}
$user_data = $objUser->getUserData($journal_user_key);
if (!isset($objHtml) || !is_object($objHtml)){
	if (!class_exists('InteractHtml')) {
		require_once('../../includes/lib/html.inc.php');
	}
	$objHtml = new InteractHtml();
}
if(!isset($objTags) || !is_object($objTags)) {
	if (!class_exists('InteractTags')){
		require_once($CONFIG['BASE_PATH'].'/includes/lib/tags.inc.php');
	}
	$objTags = new InteractTags();
}

if (isset($_POST['post_keys']) && $_POST['selected_posts_action']=='delete') {
	foreach($_POST['post_keys'] as $value) {
		if ($objJournal->checkEntryEditRights($value)) {
			$objPosts->deletePost(array('post_key'=>$value));
		}	
	}
}

require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	"header"		  => "Header.ihtml",
	"navigation"	  => "Navigation.ihtml",
	"journal"		 => "journal/JournalView.ihtml",
	"comments"		 => "modules/Comments.ihtml",
	"footer"		  => "Footer.ihtml"
));

// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);

set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);
if (($is_admin!=true && $journal_user_key!=$_SESSION['current_user_key'] && $journal_settings['default_display']!='show_all') || empty($_SESSION['current_user_key'])) {
	$action_selected_array = array('display'=>$general_strings['display']);
	$t->set_block('journal', 'AddBlock', 'AdEntryBlock');
} else {
	$action_selected_array = array('delete' => $general_strings['delete'],'display'=>$general_strings['display']);
}
$t->set_var('SPACE_KEY', $space_key);
$t->set_var('MODULE_KEY',$module_key);
$t->set_var('GROUP_KEY',$group_key);
$t->set_var('LINK_KEY',	$link_key);
$t->set_var('JOURNAL_USER_KEY', $journal_user_key);
$t->set_var('POSTED_BY', $general_strings['posted_by']);
$t->set_var('REPLY', $general_strings['reply']);
$t->set_var('REFERER', urlencode($_SERVER['REQUEST_URI']));
$t->set_var('ACTION_SELECTED_MENU', $objHtml->arrayToMenu($action_selected_array, 'selected_posts_action','',false,2));
$t->set_var('SHOW_COMMENTS', $show_comments);
if ((isset($show_comments) && $show_comments==1)|| ((!isset($show_comments) || $show_comments=='') && $journal_settings['show_comments']==1)) {
	$t->set_var('SHOW_COMMENTS_TOGGLE', $general_strings['hide_comments']);
	$t->set_var('SHOW_COMMENTS_VALUE', '0');
	$show_comments=1;
}  else {
	$t->set_var('SHOW_COMMENTS_TOGGLE', $general_strings['show_comments']);
	$t->set_var('SHOW_COMMENTS_VALUE', '1');
}

if ($show_comments==1) {
	$t->set_block('journal', 'CommentLinkBlock', 'CommLinkBlock');
	$show_comments = true;
	$parent_key = '';

} else {
	$t->set_var('COMMENTS_LINK', $general_strings['comments']);
	$parent_key = '0';
}
$limits = array();
if (isset($date_limit) && $date_limit!='') {
	$start_date = $CONN->DBDate($date_limit.'-01');
	$end_date = $CONN->DBDate($date_limit.'-31');
	$limits['date_limit'] = 'AND date_published>='.$start_date.' AND date_published<='.$end_date;
	$journal_settings['entries_to_show'] = '500';
}
$t->parse('CONTENTS', 'header', true); 
get_navigation();
$t->set_block('journal', 'PostKeysBlock', 'PKeysBlock');
//$t->set_block('journal', 'DayBlock', 'DBlock');
$t->set_block('journal', 'EntryBlock', 'EBlock');

$limits['module_key']     = $module_key;
$limits['parent_key']     = $parent_key;
$limits['tag_key']        = $tag_key;
$limits['row_limit']      = $journal_settings['entries_to_show'];
$limits['date']           = $date_limit_sql;
$limits['selected_posts'] = (isset($_POST['post_keys']) && $_POST['selected_posts_action']=='display') ? $_POST['post_keys'] : '';

if (!isset($sort_order) || $sort_order=='desc' || $sort_order=='') {
	$sort_order = 'desc';
	$t->set_var('SORT_ORDER', 'asc');
} else {
	$t->set_var('SORT_ORDER', 'desc');
}


if ($journal_settings['default_display']=='show_all') {
	$posts = $objPosts->getPostData($limits,false,$sort_order);
	$t->set_var('HEADING_STRING', $journal_strings['all_entries']);
} else {
	$limits['user_key'] = $journal_user_key;
	$posts = $objPosts->getPostData($limits,false,$sort_order);
	$t->set_var('HEADING_STRING', $user_data['first_name'].' '.$user_data['last_name']);
}
$t->set_block('comments', 'CommentBlock', 'CommBlock');
if ($journal_user_key==$_SESSION['current_user_key'] || $is_admin==true) {
	$edit_comments=true;	
}
$entry_count = $posts->RecordCount();

if ($entry_count==0) {
	$t->set_var('EBlock', '<p>'.$journal_strings['no_entries_individual'].'</p>');
	$t->set_var('SHOW_COMMENTS_TOGGLE', '');
	$t->set_var('REVERSE_SORT_ORDER', '');
	$t->set_block('journal', 'ActionSelectedBlock', 'ActSelectedBlock');
} else {
	
	if ($show_comments==true){
		$parent_limit = '(';
		while(!$posts->EOF) {
			if ($posts->CurrentRow()==0) {
				$parent_limit .= $posts->fields['post_key'];
			} else {
				$parent_limit .= ','.$posts->fields['post_key'];
			}
 			$posts->MoveNext();
		}
		$parent_limit .= ')';
		$posts->MoveFirst();	
		$comment_array = $CONN->GetArray("SELECT added_by_key,post_key, thread_key, parent_key, added_by_key, modified_by_key, subject, body, date_added, date_published, {$CONFIG['DB_PREFIX']}Users.FirstName as first_name,{$CONFIG['DB_PREFIX']}Users.LastName as last_name FROM {$CONFIG['DB_PREFIX']}posts, {$CONFIG['DB_PREFIX']}Users WHERE {$CONFIG['DB_PREFIX']}posts.added_by_key={$CONFIG['DB_PREFIX']}Users.UserKey AND parent_key!='0' AND thread_key in $parent_limit ORDER BY date_published ASC");
	} 
	while (!$posts->EOF) {
		
		if ($posts->fields['parent_key']==0) {
		
			$date_published = $CONN->UnixTimestamp($posts->fields['date_published']);
			if (($date_published<time() && $posts->fields['status_key']==1) ||$_SESSION['current_user_key']==$posts->fields['added_by_key']) {
				$t->set_var('DBlock', '');
				$t->set_var('PKeysBlock', '');
				$t->set_var('SHOW_COMMENTS', '');		
				$t->set_var('CommBlock', '');
				
				$user_key = $posts->fields['added_by_key'];
				$day = date('l j M, Y',$date_published);
				$hour = date('g:ia',$date_published);
				$referer = '/modules/journal/journalview.php?space_key='.$space_key.'&module_key='.$module_key.'&journal_user_key='.$journal_user_key.'&show_comments=1#anchor_'.$posts->fields['post_key'];
				if ($show_comments===true) {
					$t->set_block('comments', 'CommentInputBlock', 'CommInputBlock');
					$t->set_var('CommInputBlock', '<a href="entry.php?space_key='.$space_key.'&module_key='.$module_key.'&post_key='.$posts->fields['post_key'].'&journal_user_key='.$journal_user_key.'&referer='.$referer.'#add_comment">'.$general_strings['add_comment'].'</a>');
					
					$t->set_var('COMMENTS_HEADING', $general_strings['comments']);
					$has_comments = $objPosts->formatThread($comment_array,$posts->fields['post_key'],0,$edit_comments);
					if(isset($has_comments[$posts->fields['post_key']])){	
						$t->set_var('COMMENTS_HEADING', $general_strings['comments']);
					} else {
						$t->set_var('COMMENTS_HEADING', '');
					}
					$t->set_var('COMMENT_COUNT', '');
					$t->parse('SHOW_COMMENTS', 'comments', true);
				} else {
					$t->set_var('COMMENT_COUNT', $objPosts->countPosts('','',$posts->fields['post_key']));
				}
				if ($posts->fields['extended_body']!='') {
					$t->set_var('EXTENDED_BODY', '<a href="entry.php?space_key='.$space_key.'&module_key='.$module_key.'&post_key='.$posts->fields['post_key'].'&journal_user_key='.$journal_user_key.'">&hellip;'.$general_strings['more'].'</a>');
						
				} else {
					$t->set_var('EXTENDED_BODY', '');
				}
				if ($posts->fields['added_by_key']!=$journal_user_key && $journal_settings['default_display']!='show_all') {
					$t->set_var('JOURNAL_BODY_CLASS', 'journalBodyOther');		
				} else {
					$t->set_var('JOURNAL_BODY_CLASS', 'journalBodySelf');
				}
				$t->set_var('ENTRY_ANCHOR', 'anchor_'.$posts->fields['post_key']);
				$t->set_var('POST_KEY', $posts->fields['post_key']);
				$t->set_var('ADDED_BY_KEY', $posts->fields['added_by_key']);
				$t->set_var('PARENT_KEY', $posts->fields['post_key']);
				$t->set_var('THREAD_KEY', $posts->fields['post_key']);
				$t->set_var('POST_SUBJECT', $posts->fields['subject']);
				$t->set_var('POST_BODY', $objHtml->parseText($posts->fields['body']));
				$t->set_var('USER_FIRST_NAME', $posts->fields['first_name']);
				$t->set_var('POSTED_HOUR', $hour);
				$t->set_var('DRAFT', ($posts->fields['status_key']==2) ? $general_strings['draft'] : '');		
				$t->set_var('STATUS', ($date_published>time()) ? $general_strings['not_published'] : '');		
				if (!empty($_SESSION['current_user_key']) && ($is_admin==true || $user_key==$_SESSION['current_user_key'] || ($journal_user_key==$_SESSION['current_user_key'] && $journal_settings['edit_rights']=='all'))) {
//					$edit_link = get_admin_tool('entryinput.php?space_key='.$space_key.'&module_key='.$module_key.'&group_key='.$group_key.'&post_key='.$posts->fields['post_key'].'&journal_user_key='.$journal_user_key.'&action=Modify',true,$journal_strings['edit_entry']);
					
//					'<a href="entryinput.php?space_key='.$space_key.'&module_key='.$module_key.'&group_key='.$group_key.'&post_key='.$posts->fields['post_key'].'&journal_user_key='.$journal_user_key.'&action=Modify"><img src="'.$CONFIG['PATH'].'/images/tool.gif" width="16" height="16" border="0" alt="'.$journal_strings['edit_entry'].'"  /></a>';	
					$t->set_var('EDIT_LINK',get_admin_tool('entryinput.php?space_key='.$space_key.'&module_key='.$module_key.'&group_key='.$group_key.'&post_key='.$posts->fields['post_key'].'&journal_user_key='.$journal_user_key.'&action=Modify',true,$journal_strings['edit_entry']));
				} else {
		
					$t->set_var('EDIT_LINK','');
				}
//				if ($day!=$day1) {
		
					$t->set_var('DATE', $day);
//					$t->parse('DBlock', 'DayBlock', true);
			
//					$day1 = $day;
			
//				} else {
//					$t->set_var('DATE', $day);
//					$t->parse('DBlock', 'DayBlock', true);
		
//					$t->set_var('DBlock', '');
		
//				}
				//get tags for this entry
				$tag_array = $objTags->getTags($module_key, '', $posts->fields['post_key']);
				$entry_tags = '';
				$count = count($tag_array);
				for ($i=0;$i<$count;$i++) {
	
				if ($i<$count-1) {
					$delimiter = ', ';
				} else {
					$delimiter = '';					
				}
				//$t->set_var('TAG_KEY',$tag_array[$i]['tag_key']);
				$entry_tags .= '<a href="journalview.php?space_key='.$space_key.'&module_key='.$module_key.'&tag_key='.$tag_array[$i]['tag_key'].'&journal_user_key='.$journal_user_key.'">'.$tag_array[$i]['text'].'</a>'.$delimiter;
				
				}
				$t->set_var('TAG_LIST',$entry_tags);
				if ($is_admin==true || $journal_user_key==$_SESSION['current_user_key']) {
					$t->parse('PKeysBlock', 'PostKeysBlock', true);
				}
				$t->parse('EBlock', 'EntryBlock', true);
				
			}	

		}
		$posts->MoveNext();
	}

	
}


$objJournal->getSideBar($module_key, $post_key, $posts_array, $journal_user_key);
//create dropdown to select days of new items to show
$show_new_menu = $objHtml->arrayToMenu(array('0' => $general_strings['since_last_login'], '1' => $general_strings['today'], '3' => sprintf($general_strings['for_last_days'],3), '7' => sprintf($general_strings['for_last_days'],7), '30' => sprintf($general_strings['for_last_days'],30)),'show_new',$show_new,'','',true,'onchange="this.form.submit();"');
$t->set_var('SHOW_NEW_MENU',$show_new_menu);	
$t->set_var('DATE_LIMIT',$date_limit);
//now set values for any undefined variables in templates
$t->set_strings('journal',  $journal_strings, '', $errors);
$t->set_strings('comments',  $journal_strings, '', $errors);
$t->parse('CONTENTS', 'journal', true);
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p("CONTENTS");
$CONN->Close();	   
exit;	
?>
