<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* Journal entry page
*
* Displays a single journal entry with comments
*
* @package Journals
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: viewentry.php,v 1.9 2006/03/03 04:37:05 websterb4 Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../../local/config.inc.php');
require_once($CONFIG['LANGUAGE_CPATH'].'/journal_strings.inc.php');
require_once('lib.inc.php');
session_start();

//set the required variables

if ($_SERVER['REQUEST_METHOD']=='GET') {

	$module_key			= $_GET['module_key'];
	$group_key			= $_GET['group_key'];
	$journal_user_key	= $_GET['journal_user_key'];
	$post_key			= isset($_GET['post_key']) ? $_GET['post_key'] : '';	
	$tag_key			= isset($_GET['tag_key']) ? $_GET['tag_key'] : '';
		
} else {

	$module_key			= $_POST['module_key'];
	$group_key			= $_POST['group_key'];
	$journal_user_key	= $_POST['journal_user_key'];	
	$view				= $_POST['view'];
	$sort_order			= $_POST['sort_order'];
	$post_key			= isset($_POST['post_key']) ? $_POST['post_key'] : '';
	$tag_key			= isset($_POST['tag_key']) ? $_POST['tag_key'] : '';	
}
$userlevel_key	  = $_SESSION['userlevel_key'];
$space_key 	= get_space_key();
$link_key 	= get_link_key($module_key,$space_key);

//check we have the required variables
check_variables(true,true,true);

//check to see if user is logged in. 
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];
$group_access = $access_levels['groups'];
$group_accesslevel = $access_levels['group_accesslevel'][$group_key];
$is_admin = check_module_edit_rights($module_key);

$objJournal = new InteractJournal($space_key, $module_key, $group_key, $is_admin, $journal_strings);
$objJournal->setJournalSettings();
$journal_settings = $objJournal->getJournalSettings();
//if user is not an admin, and journal is closed only show current users 
//entries

if($objJournal->checkShowAll()==false && $journal_user_key!=$_SESSION['current_user_key']) {

	$journal_user_key = $_SESSION['current_user_key']; 

}
$objJournal->setJournalUserKey($journal_user_key);
//create an InteractUser class so we can retrieve user details
if (!isset($objUser) || !is_object($objUser)){
	if (!class_exists('InteractUser')) {
		require_once('../../includes/lib/user.inc.php');
	}
	$objUser = new InteractUser();
}
$user_data = $objUser->getUserData($journal_user_key);
if (!isset($objPosts) || !is_object($objPosts)){
	if (!class_exists('InteractPosts')) {
		require_once('../../includes/lib/posts.inc.php');
	}
	$objPosts = new InteractPosts();
	$objPosts->setVars($module_key, $space_key);
}


require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	"header"		  => "Header.ihtml",
	"navigation"	  => "Navigation.ihtml",
	"journal"		 => "journal/ViewEntry.ihtml",
	"comments"		 => "modules/Comments.ihtml",
	"footer"		  => "Footer.ihtml"
));

// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);

set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);
$t->set_block('comments', 'DeleteBlock', 'DelBlock');
if ($is_admin!=true && $journal_user_key!=$_SESSION['current_user_key']) {
	$t->set_block('journal', 'AddBlock', 'AdEntryBlock');
}
$t->set_var('SPACE_KEY', $space_key);
$t->set_var('MODULE_KEY',$module_key);
$t->set_var('GROUP_KEY',$group_key);
$t->set_var('LINK_KEY',	$link_key);
$t->set_var('JOURNAL_USER_KEY', $journal_user_key);
$t->set_var('HEADING_STRING', $user_data['first_name'].' '.$user_data['last_name']);
$t->set_var('POSTED_BY', $general_strings['posted_by']);
$t->set_var('REPLY', $general_strings['reply']);
if ($journal_settings['default_display']=='show_all') {
	$t->set_var('HEADING_STRING', '<a href="journalview.php?space_key='.$space_key.'&module_key='.$module_key.'&journal_user_key='.$journal_user_key.'">'.$journal_strings['all_entries'].'</a>');
} else {
	$t->set_var('HEADING_STRING', '<a href="journalview.php?space_key='.$space_key.'&module_key='.$module_key.'&journal_user_key='.$journal_user_key.'">'.$user_data['first_name'].' '.$user_data['last_name'].'</a>');
}

if (!isset($objHtml) || !is_object($objHtml)){
	if (!class_exists('InteractHtml')) {
		require_once('../../includes/lib/html.inc.php');
	}
	$objHtml= new InteractHtml();
}
$objHtml->setTextEditor($t, $_SESSION['auto_editor'], 'body');

$t->parse('CONTENTS', 'header', true); 
get_navigation();
$t->set_block('journal', 'PostKeysBlock', 'PKeysBlock');
//$t->set_block('journal', 'DayBlock', 'DBlock');
$t->set_block('journal', 'EntryBlock', 'EBlock');
$t->set_var('REFERER', urlencode($_SERVER['REQUEST_URI']));
$limits['module_key']=$module_key;
$limits['thread_key']=$post_key;
$posts_array = $objPosts->getPostData($limits,true);
$entry_count = count($posts_array);
$t->set_block('comments', 'CommentBlock', 'CommBlock');

if ($posts_array->EOF) {
	
} else {
	
	for ($i=0;$i<$entry_count;$i++) {
		
		if ($posts_array[$i]['post_key']==$post_key) {
			$date_published = $CONN->UnixTimestamp($posts_array[$i]['date_published']);
			if (($date_published<time() && $posts_array[$i]['status_key']==1) ||$_SESSION['current_user_key']==$posts_array[$i]['added_by_key']) {
				$t->set_var('DBlock', '');
				$t->set_var('PKeysBlock', '');
				$t->set_var('SHOW_COMMENTS', '');		
				$t->set_var('CommBlock', '');
			

				$user_key = $posts_array[$i]['added_by_key'];
				$day = date('l j M, Y',$date_published);
				$hour = date('g:i a',$date_published);
				$has_comments = $objPosts->formatThread($posts_array,$posts_array[$i]['post_key']);
				if(isset($has_comments[$posts_array[$i]['post_key']])){	
					$t->set_var('COMMENTS_HEADING', $general_strings['comments']);
				} else {
					$t->set_var('COMMENTS_HEADING', '');
				}
				$t->parse('SHOW_COMMENTS', 'comments', true);
				if ($posts_array[$i]['extended_body']!='') {
					$t->set_var('EXTENDED_BODY', $posts_array[$i]['extended_body']);
				} else {
					$t->set_var('EXTENDED_BODY', '');
				}
				if ($posts_array[$i]['added_by_key']!=$journal_user_key && $journal_settings['default_display']!='show_all') {
					$t->set_var('JOURNAL_BODY_CLASS', 'journalBodyOther');		
				} else {
					
					$t->set_var('JOURNAL_BODY_CLASS', 'journalBodySelf');
				}
				$t->set_var('POST_KEY', $posts_array[$i]['post_key']);
				$t->set_var('PARENT_KEY', $posts_array[$i]['post_key']);
				$t->set_var('THREAD_KEY', $posts_array[$i]['post_key']);
				$t->set_var('POST_SUBJECT', $posts_array[$i]['subject']);
				$t->set_var('POST_BODY', $objHtml->parseText($posts_array[$i]['body']));
				$t->set_var('USER_FIRST_NAME', $posts_array[$i]['first_name']);
				$t->set_var('POSTED_HOUR', $day.' '.$hour);
				$t->set_var('DRAFT', ($posts_array[$i]['status_key']==2) ? $general_strings['draft'] : '');		
				$t->set_var('STATUS', ($date_published>time()) ? $general_strings['not_published'] : '');		
				if ($is_admin==true || $user_key==$_SESSION['current_user_key']) {
			
					$edit_link = get_admin_tool('entryinput.php?space_key='.$space_key.'&module_key='.$module_key.'&group_key='.$group_key.'&post_key='.$posts_array[$i]['post_key'].'&journal_user_key='.$journal_user_key.'&action=Modify');
					$t->set_var('EDIT_LINK',$edit_link);
				
				} else {
		
					$t->set_var('EDIT_LINK','');
				}
//				if ($day!=$day1) {
		
					$t->set_var('DATE', $day);
//					$t->parse('DBlock', 'DayBlock', true);
			
//					$day1 = $day;
			
//				} else {
//					$t->set_var('DBlock', '');
//				}
				//get tags for this entry
				echo "test";
				$tag_array = $objTags->getTags($module_key, '', $post_key);
				$entry_tags = '';
				$count = count($tag_array);
				for ($i=0;$i<$count;$i++) {
	
				if ($i<$count-1) {
					$delimiter = ', ';
				} else {
					$delimiter = '';					
				}
				$entry_tags .= '<a href="journalview.php?space_key='.$space_key.'&module_key='.$module_key.'&tag_key='.$tag_array[$i]['tag_key'].'&journal_user_key='.$journal_user_key.'">'.$tag_array[$i]['text'].'</a>'.$delimiter;
				
				}
				
				$t->set_var('TAG_LIST',$entry_tags);
				if ($is_admin==true || $journal_user_key==$_SESSION['current_user_key']) {
					$t->parse('PKeysBlock', 'PostKeysBlock', true);
				}
				$t->parse('EBlock', 'EntryBlock', true);
		
			}
		}	
	
	}

}

$objJournal->getSideBar($module_key, $post_key, $posts_array, $journal_user_key);

$t->set_var('SUBMIT_BUTTON',$general_strings['add']);	
//now set values for any undefined variables in templates
$t->set_strings('journal',  $journal_strings, '', $errors);
$t->set_strings('comments',  $journal_strings, '', $errors);
$t->parse('CONTENTS', 'journal', true);
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p("CONTENTS");
$CONN->Close();	   
exit;	
?>
