<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* InteractKB Class
*
* Contains the InteractKB class for all methods and datamembers related
* to adding, modifying and viewing Knowledgebase items
*
* @package KnowledgeBase
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: lib.inc.php,v 1.32 2006/03/24 00:33:59 glendavies Exp $
* 
*/

/**
* A class that contains methods for adding/modifying KnowledgeBase info
* 
* This class is part of the Interact online learning and collaboration platform. 
* It contains methods for retrieving,displying and modifying KnowledgeBase data 
* 
* @package KnowledgeBase
* @author Glen Davies <glen.davies@cce.ac.nz>
*/

class InteractKB {

	/**
	* space key of current knowledgebase
	* @access private
	* @var int 
	*/
	var $_space_key = '';

	/**
	* module key of current knowledgebase
	* @access private
	* @var int 
	*/
	var $_module_key = '';
	
	/**
	* group key of current knowledgebase
	* @access private
	* @var int 	
	*/
	var $_group_key = '';
	
	/**
	* user key of current user
	* @access private
	* @var int 
	*/
	var $_user_key = '';
	
	/**
	* admin status of current user
	* @access private
	* @var true/false 	
	*/
	var $_is_admin = '';
	
	/**
	* array of language strings for quiz module
	* @access private
	* @var array 
	*/
	var $_kb_strings = '';
	
	/**
	* array of settings for current quiz
	* @access private
	* @var array 	
	*/
	var $_kb_data = '';
	
		
	
	/**
	* Constructor for InteractQuiz Class. Sets required variables
	*
	* @param  int $space_key  key of current space
	* @param  int $module_key  key of current module	
	* @param  int $group_key  key of current group
	* 
	*/
	
	function InteractKB($space_key,$module_key,$group_key,$is_admin,$kb_strings) {
	
		$this->_space_key	= $space_key;
		$this->_module_key  = $module_key;
		$this->_group_key	= $group_key;
		$this->_is_admin 	= $is_admin;
		$this->_kb_strings  = $kb_strings;				
		$this->_user_key 	= $_SESSION['current_user_key'];						
		
	} //end InteractKB
	
	
	/**
	* Constructor for InteractQuiz Class. Sets required variables
	*
	* @param  int $module_key  key of current module	
	* @param  return $kb_data  array of selected kb settings
	* 
	*/
	
	function getKbData($module_key) {
	
		global $CONN, $CONFIG;		
		
		$sql = "SELECT AccessLevelKey, FilePath FROM {$CONFIG['DB_PREFIX']}KBSettings WHERE ModuleKey='$module_key'";

		$rs = $CONN->Execute($sql);
		while (!$rs->EOF) {
	 
			$kb_data['access_level_key']	= $rs->fields[0];
			$kb_data['file_path']			= $rs->fields[1];
			$rs->MoveNext();
		 
		}

		$this->_kb_data = $kb_data;
		return $kb_data;			
		
	} //end getKbData
	
	/**
	* Check form input for a inputing a category
	*
	* @param  int $category_key  key of category
	* @param  int $parent_key  key of parent category
	* @param  string $category_name  name field of category		
	* @return array $errors array of any errors found
	* 
	*/
	
	function checkFormCategory($category_name, $category_key='', $parent_key='') {
	
		global $general_strings;
		$errors = array();
		
		//check that we have name
		if (!$category_name || $category_name=='') {
		
			$errors['name'] = $general_strings['no_name'];
		
		}
		
		//check that we have a question
		if ((isset($category_key) && $category_key!='') && ($category_key==$parent_key)) {
		
			$errors['parent'] = $this->_kb_strings['own_parent'];
		
		} 

		return $errors;
							
		
	} //end checkFormCategory
	
	/**
	* Add a new category
	*
	* @param  int $category_key  key of category
	* @param  int $parent_key  key of parent category
	* @param  string $category_name  name field of category		
	* @return array $errors array of any errors found
	* 
	*/
	
	function addCategory($category_name, $parent_key='') {
	
		global $CONN, $CONFIG;

		$name	 = $CONN->qstr($category_name);
		$CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBCategories(Name, ParentKey,  ModuleKey) VALUES ($name, '$parent_key', '$this->_module_key')");
		echo  $CONN->ErrorMsg();
		$category_key = $CONN->Insert_ID();
			
		return $category_key;
						
	} //end addCategory
	
	/**
	* Get name and parent data for a given category
	*
	* @param  int $category_key  key of category
	* @param  string $category_name  name field of category		
	* @return array $category_data array of category data
	* 
	*/
	
	function getCategoryData($category_key) {
	
		global $CONN, $CONFIG;

		$rs = $CONN->Execute("SELECT Name, ParentKey FROM {$CONFIG['DB_PREFIX']}KBCategories WHERE CategoryKey='$category_key'");

		while (!$rs->EOF) {

			$category_data['name']	   = $rs->fields[0];
			$category_data['parent_key'] = $rs->fields[1];
			$rs->MoveNext();
			
		}
		$rs->Close();	
		return $category_data;
						
	} //end getCategoryData		

	/**
	* modify and existing category
	*
	* @param  int $category_key  key of category
	* @param  int $parent_key  key of parent category
	* @param  string $category_name  name field of category
	* @return true
	* 
	*/
	
	function modifyCategory($category_key, $category_name, $parent_key) {
	
		global $CONN, $CONFIG;

		$name	 = $CONN->qstr($category_name);
		$CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBCategories SET Name=$name, ParentKey='$parent_key' WHERE CategoryKey='$category_key'");

		return true;
						
	} //end modifyCategory
	
	/**
	* Delete a category
	*
	* @param  int $category_key  key of category to delete
	* @param  string $delete_option action to take with attached items
	* @param  int $move_to_category if moving attached items category to move them to		
	* @return true 
	* 
	*/
	
	function deleteCategory($category_key, $delete_option, $move_to_key) {
	
		global $CONN, $CONFIG;
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBCategories WHERE CategoryKey='$category_key'");
		 
		if ($delete_option=='delete' && !empty($category_key)) {
		
			$rs = $CONN->Execute("SELECT EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks WHERE CategoryKey='$category_key'");
			
			while (!$rs->EOF) {
			
				$entry_key = $rs->fields[0];
				$this->deleteEntry($entry_key);
				$rs->MoveNext();
			
			}
			
			$rs->Close();
			
			//now delete any sub categories
			
			$rs = $CONN->Execute("SELECT CategoryKey FROM {$CONFIG['DB_PREFIX']}KBCategories WHERE ParentKey='$category_key'");
			
			while (!$rs->EOF) {
			
				$child_key = $rs->fields[0];
				$this->deleteCategory($child_key, $delete_option, $move_to_key);
				$rs->MoveNext();
			
			}						
		
		} else if (!empty($category_key)){
		
			 $CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks SET CategoryKey='$move_to_key' WHERE CategoryKey='$category_key'");
			 $CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBCategories SET ParentKey='$move_to_key' WHERE ParentKey='$category_key'");
		
		}		
		
		return true ;
		
	} //end deleteCategories()			
	
	/**
	* Check form input for a inputing a template
	*
	* @param  int $template_key  key of template
	* @param  int $parent_key  key of parent template
	* @param  string $template_name  name field of template		
	* @return array $errors array of any errors found
	* 
	*/
	
	function checkFormTemplate($template_data) {
	
		global $general_strings;
		$errors = array();
		
		//check that we have name
		if (!$template_data['name'] || $template_data['name']=='') {
		
			$errors['name'] = $general_strings['no_name'];
		
		}
		

		return $errors;
							
		
	} //end checkFormTemplate
	
	/**
	* Add a new template
	*
	* @param  int $template_key  key of template
	* @param  string $template_name  name field of template		
	* @return array $errors array of any errors found
	* 
	*/
	
	function addTemplate($template_data) {
	
		global $CONN, $CONFIG;

		$name			= $CONN->qstr($template_data['name']);
		$description	= $CONN->qstr($template_data['description']);
		$summary_fields	= $CONN->qstr($template_data['summary_fields']);
		$date_added	 = $CONN->DBDate(date('Y-m-d H:i:s'));	
		
		if ($template_data['referer']=='admin') {
		
			$type_key=0;
		
		} else {
		
			$type_key = 1;
		
		}
		
		$CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBTemplates(TypeKey, Name, Description, SummaryFields, AddedByKey, DateAdded) VALUES ('$type_key', $name, $description, $summary_fields, '$this->_user_key', $date_added)");
		
		echo  $CONN->ErrorMsg();
		
		$template_key = $CONN->Insert_ID();
		return $template_key;
						
	} //end addTemplate
	

	/**
	* modify and existing template
	*
	* @param  int $template_data  data of template to modify
	* @return true
	* 
	*/
	
	function modifyTemplate($template_data) {
	
		global $CONN, $CONFIG;

		$name	 		= $CONN->qstr($template_data['name']);
		$description	= $CONN->qstr($template_data['description']);
		$summary_fields	= $CONN->qstr($template_data['summary_fields']);		
		$template_key	= $template_data['template_key'];

		if ($CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBTemplates SET Name=$name, Description=$description, SummaryFields=$summary_fields WHERE TemplateKey='$template_key'")==true) {
		
			return $this->_kb_strings['template_modified'];
		
		} else {
		
			$message = $this->_kb_strings['template_modify_error'].' - '.$CONN->ErrorMsg();
			return $message;
			
		}
						
	} //end modifyTemplate
	
	/**
	* Remove template from current Knowledge base
	*
	* @param  array $template_keys  keys of templates to remove
	* @param  int $module_key key of kb to remove templates from
	* @param  boolean $remove_entries if one then also remove entries attached to this template		
	* @return true 
	* 
	*/
	
	function removeTemplatesFromKb($template_keys, $module_key, $remove_entries=0) {
	
		global $CONN, $CONFIG;
		
		if (isset($template_keys) && is_array($template_keys)) {
		
			foreach ($template_keys as $value) {
			
				$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks WHERE TemplateKey='$value' AND ModuleKey='$module_key'");

				if ($remove_entries==1) {
		
					$rs = $CONN->Execute("SELECT EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntries WHERE TemplateKey='$value' AND ModuleKey='$module_key'");
			
					while (!$rs->EOF) {
			
						$entry_key = $rs->fields[0];
						$this->deleteEntry($entry_key);
						$rs->MoveNext();
			
					}
					
					$rs->Close();
					
				}
			
			}			
		
		}
	
		return true ;
		
	} //end removeTemplatesFromKb()			
	
	/**
	* Delete a template from the system
	*
	* @param  int $template_key  key of template to remove
	* @param  boolean true if successful		
	* @return true 
	* 
	*/
	
	function deleteTemplate($template_key) {
	
		global $CONN, $CONFIG;
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBTemplates WHERE TemplateKey='$template_key'");
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks WHERE TemplateKey='$template_key'");
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBFields WHERE TemplateKey='$template_key'");		

		$rs = $CONN->Execute("SELECT EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntries WHERE TemplateKey='$template_key'");
		
		while (!$rs->EOF) {
			
			$entry_key = $rs->fields[0];
			$this->deleteEntry($entry_key);
			$rs->MoveNext();
			
		}
					
		$rs->Close();
		return true ;
		
	} //end removeTemplatesFromKb()		
	
	/**
	* Get an array of available templates
	*
	* @return array $template_array an array of available templates 
	* 
	*/
	
	function getTemplateArray($space_key='', $scope='all', $module_key='', $referer='', $level_key='3') {
	
		global $CONN, $CONFIG;
		
		if (isset($space_key) && $space_key!='') {
		
			switch ($scope) {
			
				case all:
				
					if ($referer=='admin' && $level_key==1) {
					
						$sql = "SELECT TemplateKey, Name FROM {$CONFIG['DB_PREFIX']}KBTemplates WHERE (TypeKey='0') ORDER BY Name";
						
					} else {
					
						$sql = "SELECT TemplateKey, Name FROM {$CONFIG['DB_PREFIX']}KBTemplates WHERE (AddedByKey='$this->_user_key') AND TypeKey!='0' ORDER BY Name";
					
					}
					
				break;
				
				case not_selected:

	$sql = "SELECT {$CONFIG['DB_PREFIX']}KBTemplates.TemplateKey, Name, {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks.ModuleKey FROM  {$CONFIG['DB_PREFIX']}KBTemplates LEFT JOIN {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks ON {$CONFIG['DB_PREFIX']}KBTemplates.TemplateKey={$CONFIG['DB_PREFIX']}KBModuleTemplateLinks.TemplateKey WHERE ((AddedByKey='$this->_user_key') OR (TypeKey='0')) AND (ModuleKey!='$module_key' OR ModuleKey IS NULL) ORDER BY Name";	
							
				break;
				
				case module_only:
				
					$sql = "SELECT {$CONFIG['DB_PREFIX']}KBTemplates.TemplateKey, Name FROM {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks, {$CONFIG['DB_PREFIX']}KBTemplates WHERE {$CONFIG['DB_PREFIX']}KBTemplates.TemplateKey={$CONFIG['DB_PREFIX']}KBModuleTemplateLinks.TemplateKey AND (ModuleKey='$this->_module_key') ORDER BY Name";
					
				break;
								
			} 
			
			
		} else {
			
			$sql = "SELECT TemplateKey, Name FROM {$CONFIG['DB_PREFIX']}KBTemplates WHERE TypeKey='0' ORDER BY Name";
			
		}
					
		$rs = $CONN->Execute($sql);
		echo $CONN->ErrorMsg();
		$template_array = array();
		while (!$rs->EOF) {
			
			$template_array[$rs->fields[0]] = $rs->fields[1];
			$rs->MoveNext();
			
		}
			
		$rs->Close();
			
		
		return $template_array;

		
	} //end getTemplateArray()		
	
	/**
	* Add an selected templates to the current module
	*
	* @param array $template_keys array of template keys to add to current module
	* @param int $module_key  key of module to add templates to	
	* @return true if successful 
	* 
	*/
	
	function addTemplatesToKb($template_keys, $module_key) {
	
		global $CONN, $CONFIG;

		if (is_array($template_keys)) {
		
			foreach ($template_keys as $value) {
			
				$rs = $CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks(ModuleKey, TemplateKey) VALUES ('$module_key','$value')");
				
			}
			
			return true;
			
		} else {
		
			return false;
		
		}
		
	} //end addTemplatesToKb()		
	
	/**
	* Get template data
	*
	* @param int $template_key key of template to get data for
	* @return array $template_data array of data for selected template 
	* 
	*/
	
	function getTemplateData($template_key) {
	
		global $CONN, $CONFIG;
	
		$rs = $CONN->Execute("SELECT Name, Description, SummaryFields FROM {$CONFIG['DB_PREFIX']}KBTemplates WHERE TemplateKey='$template_key'");

		if ($rs->EOF) {
		
			return false;
		
		} else {
		
			$template_data=array();
			
			while (!$rs->EOF) {
			
				$template_data['name'] = $rs->fields[0];
				$template_data['description'] = $rs->fields[1];
				$template_data['summary_fields'] = $rs->fields[2];				
				$rs->MoveNext();
			
			}
			
			return $template_data;
		
		}
		
				
	} //end getTemplatesData()		
	
	/**
	* Get template fields
	*
	* @param int $template_key key of template to get fields for
	* @return array $template_fields array of fields for selected template 
	* 
	*/
	
	function getTemplateFields($template_key) {
	
		global $CONN, $CONFIG;
	
		$rs = $CONN->Execute("SELECT FieldKey, TypeKey FROM {$CONFIG['DB_PREFIX']}KBFields WHERE TemplateKey='$template_key' ORDER By DisplayOrder");

		if ($rs->EOF) {
		
			return false;
		
		} else {
		
			$field_data=array();
			
			while (!$rs->EOF) {
			
				$field_data[$rs->fields[0]] = $rs->fields[1];
				$rs->MoveNext();
			
			}
			
			return $field_data;
		
		}
		
				
	} //end getTemplateFields()						
	
	/**
	* Add a new field
	*
	* @param  array $field_data  array of field data
	* @return string $message success or failure message 
	* 
	*/
	
	function addField($field_data) {
	
		global $CONN, $CONFIG;

		$name			= $CONN->qstr($field_data['name']);
		$description	= $CONN->qstr($field_data['description']);
		$display_order	= $CONN->qstr($field_data['display_order']);
		$template_key	= $field_data['template_key'];
		$type_key		= isset($field_data['type_key'])? $field_data['type_key']: '1';
		$lines			= isset($field_data['lines'])? $CONN->qstr($field_data['lines']): '1';		
		$date_added	 = $CONN->DBDate(date('Y-m-d H:i:s'));	
			
		if ($CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBFields(TemplateKey, Name, Description, TypeKey, DisplayOrder, NumberOfLines, AddedByKey, DateAdded) VALUES ('$template_key', $name, $description, '$type_key', $display_order, $lines, '$this->_user_key', $date_added)")==true) {
		
			return $this->_kb_strings['field_added'];				
		
		} else {
		
			return $this->_kb_strings['field_add_error'].' - '.$CONN->ErrorMsg();		
		
		}

						
	} //end addField	
	
	/**
	* Modify fields
	*
	* @param  array $field_data  array of field data
	* @return string $message success or failure message 
	* 
	*/
	
	function modifyFields($field_data) {
	
		global $CONN, $CONFIG;

		if (isset($field_data['field_keys']) && is_array($field_data['field_keys'])) {
		
			foreach ($field_data['field_keys'] as $field_key) {

				if (isset($field_data[$field_key.'_remove']) && $field_data[$field_key.'_remove']==1) {
				
					$this->deleteField($field_key);
				
				} else {
				
					$name			= $CONN->qstr($field_data[$field_key.'_name']);
					$description	= $CONN->qstr($field_data[$field_key.'_description']);
					$display_order	= $CONN->qstr($field_data[$field_key.'_display_order']);
					$lines			= isset($field_data[$field_key.'_lines'])? $CONN->qstr($field_data[$field_key.'_lines']): '1';		
					$date_modified	= $CONN->DBDate(date('Y-m-d H:i:s'));	
			
					if ($CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBFields SET Name=$name, Description=$description, DisplayOrder=$display_order,  NumberOfLines=$lines, ModifiedByKey='$this->_user_key', DateModified=$date_modified WHERE FieldKey='$field_key'")==false) {
		
						return $this->_kb_strings['field_modify_error'].' - '.$CONN->ErrorMsg();				
		
					}
				
				} 
			
			}
				
			return $this->_kb_strings['fields_modifed'];
		
		}
						
	} //end modifyFields		
	
	/**
	* Generate template input form
	*
	* @param  int $template_key key of template to generate form for
	* @param  obj $t template object
	* @return true 
	* 
	*/
	
	function getTemplateInputForm($template_key, &$t, $entry_key='', $action='') {
	
		global $CONN, $CONFIG;

		$rs = $CONN->Execute("SELECT FieldKey, TypeKey, Name, NumberOfLines, Description FROM {$CONFIG['DB_PREFIX']}KBFields WHERE TemplateKey='$template_key' ORDER BY DisplayOrder");
		
		if ($rs->EOF) {
		
			$t->set_block('body', 'TemplateFormBlock', 'TFBlock');
			$t->set_var('TFBlock',$this->_kb_strings['no_fields']);	
		
		} else {
		if (!class_exists('InteractHtml')) {

	require_once('../../includes/lib/html.inc.php');
	
}

			$html = new InteractHtml();
			while (!$rs->EOF) {
			

				$t->set_var('HTEBlock','');
				$t->set_var('FIELD_DESCRIPTION','');
				
				if ($action=='modify' && $entry_key!='') {
				
					$field_data = $this->getFieldData($rs->fields['0'], $entry_key);
					
				} else {
				
					$field_data = '';
					
				}
				
				$t->set_var('FIELD_NAME',$rs->fields['2']);
				$t->set_var('FIELD_KEY',$rs->fields['0']);
				$field_description = nl2br($rs->fields[4]);
				$field_description = preg_replace ('/\r/', '', $field_description);
				$field_description = preg_replace ('/\n/', '', $field_description);
				$field_description = preg_replace ('/;/', '\;', $field_description);
				$field_description = preg_replace ('/"/', '\'', $field_description);
				
				$field_description = addslashes($field_description);
				$t->set_var('FIELD_DESCRIPTION',$field_description);
				
				if ($rs->fields['3']<=1) {
				
					$t->set_var('HTEBlock','');
					
				} else {
				
					$t->parse('HTEBlock', 'HtmlEditorBlock', true);
					
				}
				
				switch($rs->fields[1]) {
				
					case 1:
					
						if ($rs->fields[3]<2) { 
							
							$t->set_var('FIELD_INPUT','<input type="text" id="'.$rs->fields['0'].'" name="'.$rs->fields['0'].'" value="'.$field_data.'" size="40"/>');
							
						} else {
						
							$t->set_var('FIELD_INPUT','<textarea id="'.$rs->fields['0'].'" name="'.$rs->fields['0'].'" cols="58" rows="'.$rs->fields['3'].'">'.$field_data.'</textarea>');
$html->setTextEditor($t, 0, $rs->fields['0']);
						
						}
					
					break;
					
					case 2:
					
						$t->set_var('FIELD_INPUT','<input type="text" id="'.$rs->fields['0'].'" name="'.$rs->fields['0'].'" value="'.$field_data.'" />');
											
					break;
					
					case 3:
					
						$t->set_var('FIELD_INPUT','<input type="file" id="'.$rs->fields['0'].'" name="'.$rs->fields['0'].'" />');
											
					break;
				
				}
				
				$t->parse('TFBlock', 'TemplateFieldBlock', true);			
				$rs->MoveNext();
			
			}
			
		}

						
	} //end getTemplateInputForm()		
	
	/**
	* Get data for given field and entry
	*
	* @param  int $field_key  key of field to get data for
	* @param  int $entry_key  key of entry to get data for	
	* @return string $data data for given field and entry 
	* 
	*/
	
	function getFieldData($field_key, $entry_key) {
	
		global $CONN, $CONFIG;
		
		$rs = $CONN->Execute("SELECT Data FROM {$CONFIG['DB_PREFIX']}KBEntryData WHERE EntryKey='$entry_key' AND FieldKey='$field_key'");
		
		while (!$rs->EOF) {
		
			$data = $rs->fields[0];
			$rs->MoveNext();
		
		}
		
		return $data;
		
	} //end getFieldData
	
	/**
	* Get array of categories for given entry
	*
	* @param  int $entry_key  key of entry to get data for	
	* @return array $category_keys array of categories entry is attached to 
	* 
	*/
	
	function getEntryCategories($entry_key) {
	
		global $CONN, $CONFIG;
		
		$rs = $CONN->Execute("SELECT CategoryKey FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks WHERE EntryKey='$entry_key'");
		
		$category_keys = array();
		$n=0;
		while (!$rs->EOF) {
		
			$category_keys[$n] = $rs->fields[0];
			$n++;
			$rs->MoveNext();
		
		}
		
		return $category_keys;
		
	} //end getEntryCategories

	/**
	* Add a new entry
	*
	* @param  array $entry_data  array of entry data
	* @return string $message success or failure message 
	* 
	*/
	
	function addEntry($entry_data) {
	
		global $CONN, $CONFIG, $general_strings;

		$name			= $CONN->qstr($field_data['name']);
		$date_added	 = $CONN->DBDate(date('Y-m-d H:i:s'));	
		$template_key	= $entry_data['template_key'];
		$module_key		= $entry_data['module_key'];
		if (!isset($entry_data['status_key']) || $entry_data['status_key']==0) {
		
			$status_key	= 2;
			
		} else {
		
			$status_key	= $entry_data['status_key'];
		
		}
		
		if ($CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBEntries(TemplateKey, ModuleKey,  AddedByKey, DateAdded, StatusKey) VALUES ('$template_key', '$module_key','$this->_user_key', $date_added, '$status_key')")===false) {

			return $general_strings['error'].' - '.$CONN->ErrorMsg();				
		
		}
		 
		$entry_key = $CONN->Insert_ID();
		
		//now get all the field details for this template
		
		$template_fields = $this->getTemplateFields($template_key);
		
		foreach ($template_fields as $key => $value) {
		
			//see if it is a file field
			
			if ($value==3 && isset($_FILES[$key]['name']) && $_FILES[$key]['name']!='') {
			
				$data = $CONN->qstr($this->addFile($key, $entry_key, $module_key));
			
			} else {
			
				$data = $CONN->qstr($entry_data[$key]);
			
			}
			
			if ($CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBEntryData(EntryKey, FieldKey, Data) VALUES ('$entry_key', '$key',$data)")===false) {
		
				return $general_strings['error'].' - '.$CONN->ErrorMsg();				
		
			}		
				
		}
		
		//now add any category links
		
		if (is_array($entry_data['category_keys'])) {
		
			$this->addEntryCategoryLinks($entry_key, $entry_data['category_keys']);	
		
		}
		
		return $this->_kb_strings['entry_add_success'];
						
	} //end addEntry		
	
	/**
	* Modify an existing entry
	*
	* @param  array $entry_data  array of entry data
	* @return string $message success or failure message 
	* 
	*/
	
	function modifyEntry($entry_data) {
	
		global $CONN, $CONFIG, $general_strings;

		$kb_data 	= $this->getKbData($this->_module_key);
		$file_path 	= $CONFIG['MODULE_FILE_SAVE_PATH'].'/kb/'.$kb_data['file_path'].'/';
		$date_modified  = $CONN->DBDate(date('Y-m-d H:i:s'));	
		$template_key	= $entry_data['template_key'];
		$module_key		= $entry_data['module_key'];
		$entry_key 		= $entry_data['entry_key'];
		
		if (!isset($entry_data['status_key']) || $entry_data['status_key']==0) {
		
			$status_key	= 2;
			
		} else {
		
			$status_key	= $entry_data['status_key'];
		
		}
		
		if ($CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBEntries SET ModifiedByKey='$this->_user_key', DateModified=$date_modified, StatusKey='$status_key' WHERE EntryKey='$entry_key'")===false) {

			return $general_strings['error'].' - '.$CONN->ErrorMsg();				
		
		}
		 
		//now get all the field details for this template
		
		$template_fields = $this->getTemplateFields($template_key);
		
		foreach ($template_fields as $key => $value) {
		
			//see if it is a file field
			
			if ($value==3) {
			
				if (isset($_FILES[$key]['name']) && $_FILES[$key]['name']!='') {
					
					$rs = $CONN->Execute("SELECT Data FROM {$CONFIG['DB_PREFIX']}KBEntryData WHERE  {$CONFIG['DB_PREFIX']}KBEntryData.FieldKey='$field_key' AND {$CONFIG['DB_PREFIX']}KBEntryData.EntryKey='$entry_key'");
		
					while(!$rs->EOF) {
		
						$full_file_path = $file_path.$rs->fields[2];

						if (is_file($full_file_path)) {
				
							unlink($full_file_path);
				
						}
			
					
						$rs->MoveNext();
		
					}
				
					$data = $CONN->qstr($this->addFile($key, $entry_key, $module_key));
					$update = true;
				} else {

					$update = false;
				}
				
			
			} else {
			
				$data = $CONN->qstr($entry_data[$key]);
				$update = true;
			
			}
			
			//see if field exists (may have been added to template since entry added
			if ($update==true) {
				
				$rs = $CONN->Execute("SELECT EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntryData WHERE EntryKey='$entry_key' AND FieldKey='$key'");
			
				if (!$rs->EOF) {
			
					if ($CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}KBEntryData SET Data=$data WHERE EntryKey='$entry_key' AND FieldKey='$key'")===false) {
		
					return $general_strings['error'].' - '.$CONN->ErrorMsg();				
		
					}
				
				} else {
			
					if ($CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBEntryData(EntryKey, FieldKey, Data) VALUES ('$entry_key','$key', $data)")===false) {
		
						return $general_strings['error'].' - '.$CONN->ErrorMsg();	
			
			
					}
				
				}		
				
			}
			
		}
		
		//delete existing category links and  add any new category links
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks WHERE EntryKey='$entry_key'");
		if (is_array($entry_data['category_keys'])) {
		
			$this->addEntryCategoryLinks($entry_key, $entry_data['category_keys']);	
		
		}
		
		return $this->_kb_strings['entry_modify_success'];
						
	} //end modifyEntry
	
	/**
	* Get data for an entry
	*
	* @param  int $entry_key  key of entry o get data for
	* @return array $entry_data array of entry data 
	* 
	*/
	
	function getEntryData($entry_key) {
	
		global $CONN, $CONFIG;
		
		$rs = $CONN->Execute("SELECT {$CONFIG['DB_PREFIX']}KBEntries.TemplateKey, {$CONFIG['DB_PREFIX']}KBEntries.ModuleKey, {$CONFIG['DB_PREFIX']}KBEntries.AddedByKey, {$CONFIG['DB_PREFIX']}KBEntries.ModifiedByKey, {$CONFIG['DB_PREFIX']}KBEntries.DateAdded, {$CONFIG['DB_PREFIX']}KBEntries.DateModified, {$CONFIG['DB_PREFIX']}KBTemplates.Name, {$CONFIG['DB_PREFIX']}KBEntries.StatusKey FROM {$CONFIG['DB_PREFIX']}KBEntries, {$CONFIG['DB_PREFIX']}KBTemplates WHERE {$CONFIG['DB_PREFIX']}KBEntries.TemplateKey={$CONFIG['DB_PREFIX']}KBTemplates.TemplateKey AND EntryKey='$entry_key'");
		
		if ($rs->EOF) {
		
			return false;
		
		} else {
		
			$entry_data = array();
			
			while (!$rs->EOF) {
			
				$entry_data['template_key'] = $rs->fields[0];
				$entry_data['module_key'] = $rs->fields[1];
				$entry_data['added_by_key'] = $rs->fields[2];
				$entry_data['modified_by_key'] = $rs->fields[3];
				$entry_data['date_added'] = $CONN->UnixTimestamp($rs->fields[4]);
				$entry_data['date_modified'] = $CONN->UnixTimestamp($rs->fields[5]);	
				$entry_data['template_name'] = $rs->fields[6];	
				$entry_data['status_key'] = $rs->fields[7];			
				$rs->MoveNext();
			
			}
			
			return $entry_data;
			
		}
	
	} //end getEntryData()
	/**
	* Add a file for an entry
	*
	* @param  int $field_key  key of file field
	* @return string $file_path path to file 
	* 
	*/
	
	function addFile($field_key, $entry_key, $module_key) {
	
		global $CONN, $CONFIG;

		$file_name	= $_FILES[$field_key]['name'];
		$tmp_name	= $_FILES[$field_key]['tmp_name'];
		$file_name=str_replace("cgi","html",$file_name);
		$file_name=str_replace("pl","html",$file_name);
		$file_name=str_replace("phtml","html",$file_name);
		$file_name=str_replace("shtml","html",$file_name);
		$file_name=str_replace("iphp","html",$file_name);

		if ($CONFIG['ALLOW_PHP']==0) {
		
			$file_name=str_replace("php","html",$file_name);
			
		}

		$file_name=ereg_replace("[^a-z0-9A-Z._]","",$file_name);
		
		//create a diretcory to store the file in
	  
		$kb_data = $this->getKbData($module_key);
		mt_srand ((float) microtime() * 1000000);
		$subdirectory = mt_rand(1,100);
		$subdirectory_path = $CONFIG['MODULE_FILE_SAVE_PATH'].'/kb/'.$kb_data['file_path'].'/'.$subdirectory;

		if (!Is_Dir($subdirectory_path)) {

			if (!mkdir($subdirectory_path,0777)) {
		
				$message = 'There was an error adding your file';
				return $message;
						
			}
		
		} 
		
		$file_path = $subdirectory.'/'.$file_name;

  		if (!copy($tmp_name,$subdirectory_path.'/'.$file_name)) {

			$message = 'There was an error adding your file';
			return $message;
					
		} 
		
		return $file_path;
						
	} //end addFile			
	
	/**
	* Add category links for an entry
	*
	* @param  int $entry_key  key of entry to add links for
	* @param  array $category_keys  array of category keys to link to	
	* @return true
	* 
	*/
	
	function addEntryCategoryLinks($entry_key, $category_keys) {
	
		global $CONN, $CONFIG;

		//first delete any existing entries
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks WHERE EntryKey='$entry_key'");
		
		//now add new entries

		foreach ($category_keys as $value) {
		
			$CONN->Execute("INSERT INTO {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks(EntryKey, CategoryKey) VALUES ('$entry_key','$value')"); 
			echo $CONN->ErrorMsg();
		
		}			
		
		return true;
		
	} //end addEntryCategoryLinks
	
	/**
	* Retrieve summary fields for given entry
	*
	* @param  int $entry_key  key of entry to add links for
	* @param  int $template_key  key of template for given entry	
	* @return string $summary_fields summary fields for given entry
	* 
	*/
	
	function getSummaryFields($entry_key, $template_key, $category_key) {
	
		global $CONN, $CONFIG, $general_strings;

		$template_data = $this->getTemplateData($template_key);
		
		$rs = $CONN->SelectLimit("SELECT Data FROM {$CONFIG['DB_PREFIX']}KBEntryData, {$CONFIG['DB_PREFIX']}KBFields WHERE {$CONFIG['DB_PREFIX']}KBEntryData.FieldKey={$CONFIG['DB_PREFIX']}KBFields.FieldKey AND {$CONFIG['DB_PREFIX']}KBEntryData.EntryKey='$entry_key' ORDER BY DisplayOrder", $template_data['summary_fields']);
		
		$n=0;
		
		$fields_array=array();
		
		while (!$rs->EOF) {
								
			if ($n==0) {
			
				if ($rs->fields[0]=='') {
				
					$rs->fields[0] = 'blank entry';
				
				}
				$fields_array['name'] = $rs->fields[0];
				$fields_array['fields'] .= '<a href="entry.php?space_key='.$this->_space_key.'&module_key='.$this->_module_key.'&entry_key='.$entry_key.'&category_key='.$category_key.'">'.$rs->fields[0].'</a>';
			
			} else {
			
				$fields_array['fields'] .= '<br />'.$rs->fields[0].'<br />';
												
			}
			
			$n++;
			$rs->MoveNext();
			
		}
		
		//now count number of comments and add comments link
		$comment_count = $this->countComments($entry_key);
		
		if ($comment_count>0) {
		
			$fields_array['fields'] .= "<br /><span class=\"small\"><a href=\"entry.php?space_key=$this->_space_key&module_key=$this->_module_key&entry_key=$entry_key#entry_key\">".$general_strings['comments'].'</a>('.$comment_count.')</span>';
			
		}
		
		return $fields_array;
				
	} //end getSummaryFields				
	
	/**
	* Generate a breadcrumb trail
	*
	* @param  int $category_key  key of current category
	* @param  int $template_key  key of template for given entry	
	* @return string $kb_trail linked breadcrumb trail
	* 
	*/
	
	function getTrail($category_key, $home=true, &$kb_trail) {
	
		global $CONN, $CONFIG;

		$rs = $CONN->Execute("SELECT Name, ParentKey FROM {$CONFIG['DB_PREFIX']}KBCategories WHERE CategoryKey='$category_key'");

		while (!$rs->EOF) {
		
			$name 		= $rs->fields[0];
			$parent_key	= $rs->fields[1];
			$rs->MoveNext();
					
		}
		
		if ($home==true) {
		
			$kb_trail = '<strong>'.$name.'</strong> > '.$kb_trail;
			
		
		} else {
		
			$kb_trail = '<a href="viewentries.php?space_key='.$this->_space_key.'&module_key='.$this->_module_key.'&entry_key='.$entry_key.'&category_key='.$category_key.'">'.$name.'</a> > '.$kb_trail;
				
		}

		if ($parent_key!=0) {
		
			$this->getTrail($parent_key, false, $kb_trail);
		
		} else {
		
			return true;
			
		}
				
	} //end getTrail					
	
	/**
	* Delete an entry
	*
	* @param  int $entry_key  key of entry to delete
	* @return true
	* 
	*/
	
	function deleteEntry($entry_key) {
	
		global $CONN, $CONFIG;
			
		$kb_data 	= $this->getKbData($this->_module_key);
		$file_path 	= $CONFIG['MODULE_FILE_SAVE_PATH'].'/kb/'.$kb_data['file_path'].'/';		 
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntries WHERE EntryKey=$entry_key");
		$rs = $CONN->Execute("SELECT DataKey, TypeKey, Data FROM {$CONFIG['DB_PREFIX']}KBEntryData, {$CONFIG['DB_PREFIX']}KBFields WHERE {$CONFIG['DB_PREFIX']}KBEntryData.FieldKey={$CONFIG['DB_PREFIX']}KBFields.FieldKey AND EntryKey=$entry_key");

		//see if entry has file attached, if so remove it
		
		while(!$rs->EOF) {
		
			if ($rs->fields[1]==3) {
			
				$full_file_path = $file_path.$rs->fields[2];

				if (is_file($full_file_path)) {
				
					unlink($full_file_path);
				
				}
			
			} 
					
			$rs->MoveNext();
		
		}
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntryData WHERE EntryKey=$entry_key");
		
		//find any comments and remove postuserlinks
		$rs = $CONN->Execute("SELECT post_key FROM {$CONFIG['DB_PREFIX']}posts WHERE entry_key=$entry_key");
		while(!$rs->EOF) {
		
			$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}post_user_links WHERE post_key={$rs->fields[0]}");
			$rs->MoveNext();
		
		}
		
		$rs->Close();
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}posts WHERE entry_key=$entry_key AND module_key='$this->_module_key'");		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks WHERE EntryKey=$entry_key");
		return true;
				
	} //end deleteEntry()					
	
	/**
	* Delete a field from a template
	*
	* @param  int $field_key  key of field to delete
	* @return true
	* 
	*/
	
	function deleteField($field_key) {
	
		global $CONN, $CONFIG;
			
		$kb_data 	= $this->getKbData($this->_module_key);
		$file_path 	= $CONFIG['MODULE_FILE_SAVE_PATH'].'/kb/'.$kb_data['file_path'].'/';		 
		$rs = $CONN->Execute("SELECT DataKey, TypeKey, Data FROM {$CONFIG['DB_PREFIX']}KBEntryData, {$CONFIG['DB_PREFIX']}KBFields WHERE {$CONFIG['DB_PREFIX']}KBEntryData.FieldKey={$CONFIG['DB_PREFIX']}KBFields.FieldKey AND {$CONFIG['DB_PREFIX']}KBEntryData.FieldKey='$field_key'");

		//see if entry has file attached, if so remove it
		
		while(!$rs->EOF) {
		
			if ($rs->fields[1]==3) {
			
				$full_file_path = $file_path.$rs->fields[2];

				if (is_file($full_file_path)) {
				
					unlink($full_file_path);
				
				}
			
			} 
					
			$rs->MoveNext();
		
		}
		
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBEntryData WHERE FieldKey='$field_key'");
		$CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}KBFields WHERE FieldKey='$field_key'");
		
		return true;
				
	} //end deleteField()
	
	/**
	* Count the number of comments for a given entry
	*
	* @param  int $entry_key  key of entry to count comments for
	* @return int $count number of comments
	* 
	*/
	
	function countComments($entry_key) {
	
		global $CONN, $CONFIG;
			
		$rs = $CONN->Execute("SELECT post_key FROM {$CONFIG['DB_PREFIX']}posts WHERE entry_key='$entry_key'");
		$count = $rs->RecordCount();

		return $count;
				
	} //end countComments()	
	
	/**
	* Count the number of templates linked to a knowledgebase
	*
	* @param  int $module_key  key of module to count templates for
	* @return int $count number of templates
	* 
	*/
	
	function countTemplates($module_key) {
	
		global $CONN, $CONFIG;
			
		$rs = $CONN->Execute("SELECT TemplateKey FROM {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks WHERE ModuleKey='$module_key'");
		$count = $rs->RecordCount();

		return $count;
				
	} //end countTemplates()	
	
	/**
	* Get the key of template for module that has only one template
	*
	* @param  int $module_key  key of module to count templates for
	* @return int $template_key key of template for given module
	* 
	*/
	
	function getTemplateKey($module_key) {
	
		global $CONN, $CONFIG;
			
		$rs = $CONN->Execute("SELECT TemplateKey FROM {$CONFIG['DB_PREFIX']}KBModuleTemplateLinks WHERE ModuleKey='$module_key'");
		
		while (!$rs->EOF) {
		
			$template_key = $rs->fields[0];
			$rs->MoveNext();
		
		}
		
		$rs->Close();
		
		return $template_key;
				
	} //end getTemplateKey()	
	
	/**
	* Count entries for a given category, of for entire knowledgebas 
	* @param  int $module_key  key of module to count entries for
	* @param  int $category_key  key of category to count entries for
	* @return int $entry_count total entrie
	* 
	*/
	
	function getEntryCount($module_key, $category_key='') {
	
		global $CONN, $CONFIG;
			
		if ($category_key=='') {
		
			$rs = $CONN->Execute("SELECT EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntries WHERE ModuleKey='$module_key' AND StatusKey='2'");
		
			$entry_count = $rs->RecordCount();
			$rs->Close();
			return $entry_count;
		} else {
			
			$rs = $CONN->Execute("SELECT {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks.EntryKey FROM {$CONFIG['DB_PREFIX']}KBEntryCategoryLinks, {$CONFIG['DB_PREFIX']}KBEntries WHERE  {$CONFIG['DB_PREFIX']}KBEntries.EntryKey={$CONFIG['DB_PREFIX']}KBEntryCategoryLinks.EntryKey AND CategoryKey='$category_key' AND {$CONFIG['DB_PREFIX']}KBEntries.StatusKey='2'");
		
			$entry_count = $rs->RecordCount();
			$rs->Close();
			$sub_category_count = $CONN->GetOne("SELECT COUNT(CategoryKey) FROM {$CONFIG['DB_PREFIX']}KBCategories WHERE  {$CONFIG['DB_PREFIX']}KBCategories.ParentKey='$category_key'");
		
			$entry_count = $entry_count+$sub_category_count;
			
		}
		
		return $entry_count;
					
	} //end getEntryCount()	
		
	/**
	* Returns status key of given entry 
	* @param  int $entry_key  key of entry to return status of
	* @return  int $status_key  status key of given entry
	* 
	*/
	
	function getEntryStatusKey($entry_key) {
	
		global $CONN, $CONFIG;
			
		$entry_data = $this->getEntryData($entry_key);
		
		return $entry_data['status_key'];
		
	} //end getEntryStatusKey()		
					
} //end InteractKB class	
?>