<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+
/**
* InteractSkin Class
*
* Contains the Skin class for all methods and datamembers related
* to adding, modifying Skins
*
* @package Skins
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: lib.inc.php,v 1.11.4.1 2006/04/10 23:43:07 glendavies Exp $
* 
*/

/**
* A class that contains methods for adding/modifying skins
* 
* This class is part of the Interact online learning and collaboration platform. 
* It contains methods for retrieving,displying and modifying skins 
* 
* @package Skins
* @author Glen Davies <glen.davies@cce.ac.nz>
*/

class InteractSkins {
	/**
	* method to get exisiting skin data 
	*
	* @param  int $skin_key  key of skin to get data for
	* @return array $skin_data data for selected skin
	*/
	function getSkinData($skin_key) 
	{
		global $CONN, $CONFIG;
	 	
		$rs = $CONN->Execute("SELECT BodyBackground, BodyFont, BodyBorderColour, OuterBoxBackground,  OuterBoxBorderColour,  HeaderLogo, HeaderBackground, HeaderBorderColour, InnerBoxBackground, InnerBoxBorderColour, NavBackground, NavBorderColour, ContentBackground, ContentBorderColour, Template, Name, ScopeKey, HeaderLogoWidth, HeaderLogoHeight, HeaderHeight, ServerNameColour,RawCss FROM {$CONFIG['DB_PREFIX']}Skins WHERE SkinKey='$skin_key'");
echo $CONN->ErrorMsg();
		while (!$rs->EOF) {
			$skin_data['body_background'] 			= $rs->fields[0];
			$skin_data['body_font'] 				= $rs->fields[1];
			$skin_data['body_border_colour'] 		= $rs->fields[2];
			$skin_data['outer_box_background'] 		= $rs->fields[3];
			$skin_data['outer_box_border_colour'] 	= $rs->fields[4];
			$skin_data['header_logo'] 				= $rs->fields[5];	
			$skin_data['header_background'] 		= $rs->fields[6];
			$skin_data['header_border_colour'] 		= $rs->fields[7];	
			$skin_data['inner_box_background'] 	= $rs->fields[8];
			$skin_data['inner_box_border_colour'] = $rs->fields[9];
			$skin_data['nav_background'] 			= $rs->fields[10];
			$skin_data['nav_border_colour'] 		= $rs->fields[11];	
			$skin_data['content_background'] 		= $rs->fields[12];
			$skin_data['content_border_colour'] 	= $rs->fields[13];
			$skin_data['template'] 					= $rs->fields[14];
			$skin_data['name'] 						= $rs->fields[15];
			$skin_data['scope_key'] 				= $rs->fields[16];
			$skin_data['header_logo_width']			= $rs->fields[17];			
			$skin_data['header_logo_height'] 		= $rs->fields[18];		
			$skin_data['header_height']				= $rs->fields[19];	
			$skin_data['server_name_colour']		= $rs->fields[20];	
			$skin_data['raw_css']					= $rs->fields[21];							
			$rs->MoveNext();		
		}
		$rs->Close();
		return $skin_data;

	} //end getSkinData()

	/**
	* method to get an array of available skins 
	*
	* @param  string $type 'view' for list to view, 'edit' for list to edit
	* @return array $skin_array array of $skin_key => $skin_name data
	*/
	function getSkinArray($type='view') 
	{
		global $CONN, $CONFIG;
	 	
		$user_key = $_SESSION['current_user_key'];
		switch ($type) {
			case 'view': 
				$skin_key = $this->getSkinKey($_SESSION['current_space_key']);
				$sql = "SELECT SkinKey, Name FROM {$CONFIG['DB_PREFIX']}Skins WHERE ScopeKey='1' OR UserKey='$user_key' OR SkinKey='$skin_key'";
				
			break;
			
			case 'edit':
				if($_SESSION['userlevel_key']==1) {
				$sql = "SELECT SkinKey, Name FROM {$CONFIG['DB_PREFIX']}Skins WHERE (ScopeKey='1' OR UserKey='$user_key') AND SkinKey!='1'";
				} else {
					$sql = "SELECT SkinKey, Name FROM {$CONFIG['DB_PREFIX']}Skins WHERE UserKey='$user_key' AND SkinKey!='1'";
				}
			break;			 
		}
		
		$rs = $CONN->Execute($sql);
		if ($rs->EOF) {
			return false;
		} else {
			$skin_array = array();
			while (!$rs->EOF) {
				$skin_array[$rs->fields[0]] = $rs->fields[1];
				$rs->MoveNext();		
			}
			$rs->Close();
		}
		return $skin_array;

	} //end getSkinArray()
	
	/**
	* Method to add a skin 
	*
	* @param  array $skin_data array of data to add for skin
	* @return true true if successful, error message if not
	*/
	function addSkin($skin_data) 
	{
		global $CONN, $CONFIG;
	 	
		$current_user_key = $_SESSION['current_user_key'];	
		$skin_data['name'] = $this->checkNameUnique($skin_data['name']);
		foreach ($skin_data as $key => $value) {
			$$key = $CONN->qstr($value);
		}
		
		$sql = "INSERT INTO {$CONFIG['DB_PREFIX']}Skins(Name, UserKey, Template,ScopeKey,BodyBackground, BodyFont, BodyBorderColour, OuterBoxBackground,  OuterBoxBorderColour,  HeaderLogo, HeaderLogoWidth, HeaderLogoHeight,HeaderHeight,HeaderBackground, HeaderBorderColour, ServerNameColour,InnerBoxBackground, InnerBoxBorderColour, NavBackground, NavBorderColour, ContentBackground, ContentBorderColour,RawCss) VALUES ($name, '$current_user_key',$template,$scope_key,$body_background, $body_font, $body_border, $outer_box_background, $outer_box_border, $header_logo, $header_logo_width, $header_logo_height, $header_height, $header_background, $header_border, $server_name_colour, $inner_box_background, $inner_box_border, $nav_background, $nav_border, $content_background, $content_border, $raw_css)";
		
		if ($CONN->Execute($sql)===false) {
			return $CONN->ErrorMsg();
		} else {
			return true;
		}

	} //end addSkin()	
	
	/**
	* Method to modify a skin 
	*
	* @param  array $skin_data array of data to modify for skin
	* @return true true if successful, error message if not
	*/
	function modifySkin($skin_data) 
	{
		global $CONN, $CONFIG;

		$current_user_key = $_SESSION['current_user_key'];	
		$skin_data['name'] = $this->checkNameUnique($skin_data['name'],$skin_data['skin_key']);
		if(!isset($skin_data['scope_key'])) {
			$skin_data['scope_key']=0;
		}
		foreach ($skin_data as $key => $value) {
			$$key = $CONN->qstr($value);
		}
		
		$sql = "UPDATE {$CONFIG['DB_PREFIX']}Skins SET Name=$name, UserKey='$current_user_key', Template=$template,ScopeKey=$scope_key,BodyBackground=$body_background, BodyFont=$body_font, BodyBorderColour=$body_border, OuterBoxBackground=$outer_box_background,  OuterBoxBorderColour=$outer_box_border, HeaderLogo=$header_logo, HeaderLogoWidth=$header_logo_width, HeaderLogoHeight=$header_logo_height,HeaderHeight=$header_height, HeaderBackground=$header_background, HeaderBorderColour=$header_border, ServerNameColour=$server_name_colour, InnerBoxBackground=$inner_box_background, InnerBoxBorderColour=$inner_box_border, NavBackground=$nav_background, NavBorderColour=$nav_border, ContentBackground=$content_background, ContentBorderColour=$content_border, RawCss=$raw_css WHERE SkinKey=$skin_key";
		
		if ($CONN->Execute($sql)===false) {
			return $CONN->ErrorMsg();
		} else {
			return true;
		}

	} //end modifySkin()	
	
	/**
	* Method to delete a skin 
	*
	* @param  array $skin_key key of skin to delete
	* @return true true if successful, error message if not
	*/
	function deleteSkin($skin_key) 
	{
		global $CONN, $CONFIG;

		//first update any spaces that use this skin
		$CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}Spaces SET SkinKey='1' WHERE SkinKey='$skin_key'");
		//now update any users
		$CONN->Execute("UPDATE {$CONFIG['DB_PREFIX']}Users SET SkinKey='1' WHERE SkinKey='$skin_key'");
		
		if ($CONN->Execute("DELETE FROM {$CONFIG['DB_PREFIX']}Skins WHERE SkinKey='$skin_key'")===false) {
			return $CONN->ErrorMsg();
		} else {
			return true;
		}

	} //end deleteSkin()		
	
	/**
	* method to check a users rights to edit a skin 
	*
	* @param  string $skin_key key of skin to check rights for
	* @return true true if allowed to edit, false if not
	*/
	function checkEditRights($skin_key) 
	{
		global $CONN, $CONFIG;
	 	
		if ($_SESSION['userlevel_key']==1) {
			return true;
		}
		$rs = $CONN->Execute("SELECT SkinKey FROM {$CONFIG['DB_PREFIX']}Skins WHERE SkinKey='$skin_key' AND UserKey='{$_SESSION['current_user_key']}'");
		if ($rs->RecordCount()==0) {
			return false;
		} else {
			return true;
		}
	} //end checkEditRights()
	
	/**
	* return the skin key that should be used for current page 
	* @param  int $space_key key of current space
	*
	* @return int $skin_key key of skin to use for current page
	*/
	function getSkinKey($space_key, $type_key=0) 
	{
		global $CONN, $CONFIG;
	 	
		if ($CONFIG['USER_SET_SKIN']==1) {
			if (isset($_SESSION['skin_key']) && $_SESSION['skin_key']!=0){
				return $_SESSION['skin_key'];
			} 
		}
		if ($CONFIG['ADMIN_SET_SKIN']==1 || $type_key==1) {
			$skin_key = $CONN->GetOne("SELECT {$CONFIG['DB_PREFIX']}Spaces.SkinKey FROM {$CONFIG['DB_PREFIX']}Spaces WHERE  {$CONFIG['DB_PREFIX']}Spaces.SpaceKey='$space_key'");
			if (isset($skin_key) && $skin_key!=0) {
				return $skin_key;
			}
		}
		return $CONFIG['DEFAULT_SKIN_KEY'];
	
	} //end getSkinKey()	
	
	/**
	* Check to see if an entered skin name is unique, if not make unique
	* 
	* @param string $name skin name to check
	* @param string $skin_key if modifying key of skin being modified
	* @return $name
	*/
	function checkNameUnique ($name, $skin_key='')
	{

		global $CONN, $CONFIG;

		if($skin_key=='') { 
			$rs = $CONN->Execute("SELECT SkinKey from {$CONFIG['DB_PREFIX']}Skins WHERE Name ='$name'");
			
		} else {
			$rs = $CONN->Execute("SELECT SkinKey from {$CONFIG['DB_PREFIX']}Skins WHERE Name ='$name' AND SkinKey!='$skin_key'");
			
		}
		
		if ($rs->EOF) {
		
			return $name;
			
		} else {
		
			$n = 1;
			$exists = true;
			while ($exists==true) {
			
				$new_name = $name.$n;
				$rs = $CONN->Execute("SELECT SkinKey FROM {$CONFIG['DB_PREFIX']}Skins WHERE Name='$new_name'");
				
				if ($rs->EOF) {
					$exists = false;
					return $new_name;
				} else {
				
					$n++;
				
				}
				
			}
				
		}
			
	} //end checkNameUnique

	
	
} //end InteractSkin class	
?>