<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+

/**
* Skin input page
*
* Display the page for adding and modifying new skins 
*
* @package Skins
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2001 
* @version $Id: skin_input.php,v 1.12 2006/02/12 22:38:37 websterb4 Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../local/config.inc.php');
session_start();

//get language strings
require_once($CONFIG['LANGUAGE_CPATH'].'/skin_strings.inc.php');

//set variables
$space_key 	= get_space_key();
$current_user_key	= $_SESSION['current_user_key'];
$action = isset($_POST['action'])?$_POST['action']:'';
$message = isset($_GET['message'])?$_GET['message']:'';

if ($_SERVER['REQUEST_METHOD']=='GET') {
	$referer = isset($_GET['referer'])?urldecode($_GET['referer']):'';
} else {
	$referer = isset($_POST['referer'])?urldecode($_POST['referer']):'';
}
//check we have the required variables
check_variables(true,false);

//check to see if user is logged in. If not refer to Login page.
$access_levels = authenticate();
$accesslevel_key = $access_levels['accesslevel_key'];

if (!isset($objSkins)) {
	if (!class_exists('InteractSkins')) {
		require_once('lib.inc.php');
	}
	$objSkins = new InteractSkins();
}

if ($_SERVER['REQUEST_METHOD']='POST') {

	switch ($_POST['action']) {
		
		case 'add':
			$skin_data = $_POST;
			if(!isset($skin_data['scope_key'])) {
				$skin_data['scope_key']=0;
			}
			if (!isset($_POST['name']) || $_POST['name']=='') {
				$name_error = sprint_error($general_strings['no_name']);
				$message = $general_strings['problem_below'];
			} else {
				$add = $objSkins->addSkin($skin_data);
				if ($add===true) {
					$message = urlencode($general_strings['add_success']);
					header("Location: {$CONFIG['SERVER_URL']}$referer&space_key=$space_key&message=$message#skin");
				} else {
					$message = $general_strings['problem_below'].'<br />'.$add;
				}	
			}			
		break;
		
		case 'modify':
			if ($objSkins->checkEditRights($_POST['skin_key'])===false) {
				$message = urlencode($general_strings['no_edit_rights']);
				header("Location: {$CONFIG['SERVER_URL']}$referer&space_key=$space_key&message=$message#skin");
			}
			$skin_data = $objSkins->getSkinData($_POST['skin_key']);
		break;
		
		case 'modify2':
			
			if ($objSkins->checkEditRights($_POST['skin_key'])===false) {
				$message = urlencode($general_strings['no_edit_rights']);
				header("Location: {$CONFIG['SERVER_URL']}$referer&space_key=$space_key&message=$message#skin");
			}
			switch($_POST['submit']) {
				case $general_strings['modify']:
					
					if (!isset($_POST['name']) || $_POST['name']=='') {
						$name_error = sprint_error($general_strings['no_name']);
						$message = $general_strings['problem_below'];
					} else {
						
						$modify = $objSkins->modifySkin($_POST);
						if ($modify==true) {
							$message = urlencode($general_strings['modify_success']);
							header("Location: {$CONFIG['SERVER_URL']}$referer&space_key=$space_key&message=$message#skin");
						} else {
							$message = $general_strings['problem_below'].'<br />'.$modify;
						}	
					}			
				break;
		
				case $general_strings['delete']:
					$delete = $objSkins->deleteSkin($_POST['skin_key']);
					if ($delete==true) {
						$message = urlencode($general_strings['delete_success']);
						header("Location: {$CONFIG['SERVER_URL']}$referer&space_key=$space_key&message=$message#skin");
					} else {
						$message = $general_strings['problem_below'].'<br />'.$delete;
					}
				break;
			}
		break;
	}
}

require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	'header'		=> 'Header.ihtml',
	'navigation'	=> 'Navigation.ihtml',
	'form'			=> 'skins/SkinInput.ihtml',
	'footer'		=> 'Footer.ihtml'
));

// get page details for titles and breadcrumb navigation
$page_details = get_page_details($space_key,$link_key);
$page_details['breadcrumbs'] = $page_details['breadcrumbs'].' <a href="skin_select.php?space_key='.$space_key.'">Skins</a> &raquo;';
set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);

if (!isset($action) || $action=='' || $action=='add') {
	$t->set_var('ACTION','add');
	$t->set_var('SUBMIT_BUTTON',$general_strings['add']);
	$t->set_block('form', 'DeleteBlock', 'DelBlock');
	$t->set_var('DelBlock','');
} else {
	$t->set_var('ACTION','modify2');
	$t->set_var('SUBMIT_BUTTON',$general_strings['modify']);
	$t->set_var('DELETE_BUTTON',$general_strings['delete']);
}
//generate the template menu

$d = dir($CONFIG['BASE_PATH'].'/local/skins');
$templates_array = array();
while (false !== ($entry = $d->read())) {
	if($entry == "." || $entry == "..") { 
		continue; 
	} 
	if (is_dir($CONFIG['BASE_PATH'].'/local/skins/'.$entry)) {
		$templates_array[$entry] = $entry;
	}
}
$d->close();
if (!is_object($objHtml)) {
	if (!class_exists('InteractHtml')) {
		require_once('../../includes/lib/html.inc.php');
	}
	$objHtml = new InteractHtml();
}
$alt_style_sheets='';
foreach($templates_array as $value) {
	$alt_style_sheets.='<link rel="alternate stylesheet" type="text/css" href="'.$CONFIG['PATH'].'/skins/skin.php?template='.$value.'" title="'.$value.'" />';
}
$templates_menu = $objHtml->arrayToMenu($templates_array,'template',$skin_data['template'],false,'',true,'onChange="setActiveStyleSheet(this.value)"');
$alt_style_sheets .= '<script type="text/javascript" language="javascript"  src="'.$CONFIG['PATH'].'/includes/editor/dialog.js" ></script>';
$alt_style_sheets .= '<script type="text/javascript" language="javascript"  src="'.$CONFIG['PATH'].'/includes/editor/use_dialogs.js" ></script>';
$t->set_var('META_TAGS',$alt_style_sheets);
if (isset($_POST['skin_key'])) {
	$t->set_var('SKIN_KEY',$_POST['skin_key']);
}
$t->parse('CONTENTS', 'header', true);
$font_array = array(''=>'Default','Arial, Helvetica, sans-serif'=>'Arial, Helvetica, sans-serif',
'Verdana, Arial, Helvetica, sans-serif'=> 'Verdana, Arial, Helvetica, sans-serif',
'Georgia, Times New Roman, Times, serif'=> 'Georgia, Times New Roman, Times, serif',
'Geneva, Arial, Helvetica, sans-serif'=> 'Geneva, Arial, Helvetica, sans-serif');
$default_font = isset($skin_data['body_font'])?$skin_data['body_font']:'Default';
$font_menu = $objHtml->arrayToMenu($font_array,'body_font',$default_font,false,'',false,"onChange=changeStyle('pageBody','body_font','fontFamily')");
//remove skope flag if user not server admin
if ($_SESSION['userlevel_key']!=1){
	$t->set_block('form', 'ScopeBlock', 'SBlock');
	$t->set_var('SBlock','');
}
$t->set_var('INPUT_HEADING',$skin_strings['input_heading']);
$t->set_var('TEMPLATE_STRING',$skin_strings['template']);
$t->set_var('TEMPLATES_MENU',$templates_menu);
$t->set_var('BODY_STRING',$skin_strings['body']);
$t->set_var('BACKGROUND_STRING',$skin_strings['background']);
$t->set_var('BORDER_STRING',$skin_strings['border']);
$t->set_var('FONT_STRING',$skin_strings['font']);
$t->set_var('HEADER_STRING',$skin_strings['header']);
$t->set_var('LOGO_STRING',$skin_strings['logo']);
$t->set_var('NAVIGATION_STRING',$skin_strings['navigation']);
$t->set_var('MAIN_CONTENT_STRING',$skin_strings['main_content']);
$t->set_var('OUTER_BOX_STRING',$skin_strings['outer_box']);
$t->set_var('INNER_BOX_STRING',$skin_strings['inner_box']);
$t->set_var('SERVER_NAME_STRING',$skin_strings['server_name_colour']);
$t->set_var('CSS_STRING',$skin_strings['css_string']);
$t->set_var('CSS_WARNING_STRING',$skin_strings['css_warning']);
$t->set_var('NAME_STRING',$general_strings['name']);
$t->set_var('MAKE_AVAILABLE_STRING',$skin_strings['make_available']);
$t->set_var('NAME_ERROR',isset($name_error)?$name_error:'');
$t->set_var('REFERER',$referer);
$t->set_var('FONT_MENU',$font_menu);
if (isset($skin_data) && is_array($skin_data)) {
	foreach($skin_data as $key => $value) {
		$t->set_var(strtoupper($key),$value);
	}
}
get_navigation();

$t->parse('CONTENTS', 'form', true);
$t->parse('CONTENTS', 'footer', true);

print_headers();
$t->p('CONTENTS');
$CONN->Close();	   
exit;

?>