<?php
// +------------------------------------------------------------------------+
// | This file is part of Interact.											|
// |																	  	| 
// | This program is free software; you can redistribute it and/or modify 	|
// | it under the terms of the GNU General Public License as published by 	|
// | the Free Software Foundation (version 2)							 	|
// |																	  	|	 
// | This program is distributed in the hope that it will be useful, but  	|
// | WITHOUT ANY WARRANTY; without even the implied warranty of		   		|
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	 	|
// | General Public License for more details.							 	|
// |																	  	|	 
// | You should have received a copy of the GNU General Public License		|
// | along with this program; if not, you can view it at				  	|
// | http://www.opensource.org/licenses/gpl-license.php				   		|
// +------------------------------------------------------------------------+


/**
* InteractSpace Class
*
* Contains the Space class for all methods and datamembers related
* to spaces
*
* @package Space
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2003 
* @version $Id: lib.inc.php,v 1.15 2006/03/03 04:00:31 websterb4 Exp $
* 
*/

/**
* A class that contains methods for working with spaces
* 
* This class is part of the Interact online learning and collaboration platform. 
* It contains methods for working with spaces 
* 
* @package Space
* @author Glen Davies <glen.davies@cce.ac.nz>
*/

class InteractSpace {

	/**
	* Function to check if a user is a member of a space 
	*
	* @param  int $space_key  key of group
	* @param  int $user_key  key of user
	* @return array $membership_data data for user in group - access_level, date added. return false 
	* if not member
	*/

	function checkMembership($space_key, $user_key) {

	 
		global $CONN, $CONFIG;
	 
		$sql = "SELECT AccessLevelKey, DateAdded FROM {$CONFIG['DB_PREFIX']}SpaceUserLinks WHERE SpaceKey='$space_key' AND UserKey='$user_key'";	
		$rs = $CONN->Execute($sql);

		if ($rs->EOF) {
		
			return false;
			
		} else {
		
			while (!$rs->EOF) {

				$membership_data['access_level_key'] = $rs->fields[0];
				$membership_data['date_added'] = $CONN->UnixTimeStamp($rs->fields[1]);		
 			
		
				$rs->MoveNext();
	
			}
			
			return $membership_data;
			
		}
		
		$rs->Close();
		
	} //end checkMembership()
	
	/**
	* Function to count the number of members in a space 
	*
	* @param  int $space_key  key of group
	* @return int $total_members total number of members in a group
	*/

	function countMembers($space_key, $include_leaders=true) {

	 
		global $CONN, $CONFIG;
	 
		if ($include_leaders==true) {
		
			$sql = "SELECT COUNT(UserKey) FROM {$CONFIG['DB_PREFIX']}SpaceUserLinks WHERE SpaceKey='$space_key'";
			
		} else {
		
			$sql = "SELECT COUNT(UserKey) FROM {$CONFIG['DB_PREFIX']}SpaceUserLinks WHERE SpaceKey='$group_key' AND AccessLevelKey='2'";		
		
		}  
		  
		$rs = $CONN->Execute($sql);

		if ($rs->EOF) {
		
			return false;
			
		} else {
		
			while (!$rs->EOF) {

				$total_members = $rs->fields[0];
				$rs->MoveNext();
	
			}
			
			return $total_members;
			
		}
		
		$rs->Close();
		
	} //end countMembers()
	
	/**
	* Function to count the number of new members in a space 
	*
	* @param  int $space_key  key of space
	* @param  int $user_key  key of user to find new members for	
	* @return int $new_members total number of members in a group
	*/

	function countNewMembers($space_key, $user_key) {

	 
		global $CONN, $CONFIG;

		//first of all find out the last time the user accessed this group
		
		$rs = $CONN->SelectLimit("SELECT DateAccessed FROM {$CONFIG['DB_PREFIX']}Statistics WHERE SpaceKey='$space_key' AND UserKey='$user_key' ORDER BY DateAccessed DESC", 1);
		
		if ($rs->EOF) {
		
			//user has not accessed space before so don't show new members
			
			return 0;

			
		} else {
		
			if (!isset($_SESSION['space_'.$space_key.'_last_access'])) {
			
				while (!$rs->EOF) {

					$date_accessed = $CONN->DBDate(date('Y-m-d H:i:s',$CONN->UnixTimestamp($rs->fields[0])));
					$rs->MoveNext();
	
				}
				
				$_SESSION['space_'.$space_key.'_last_access'] = $date_accessed;
				
			} else {
			
				$date_accessed = $_SESSION['space_'.$space_key.'_last_access'];
			
			}
			
			$rs->Close();
				
		} 
		
		$rs = $CONN->Execute("SELECT COUNT(UserKey) FROM {$CONFIG['DB_PREFIX']}SpaceUserLinks WHERE DateAdded>$date_accessed AND SpaceKey='$space_key'");
		
		if ($rs->EOF) {
		
			return 0;
			
		} else {
		
			while (!$rs->EOF) {

				$new_members = $rs->fields[0];
				$rs->MoveNext();
	
			}
			
			return $new_members;
			
		}
		
		$rs->Close();
		
	
		
	} //end countMembers()
		
	/**
	* Function to get component links for a given block 
	*
	* @param  int $space_key  key of space
	* @param  int $block_key  key of block to get component links for	
	* @return string ordered list of components for given block
	*/

	function getBlockComponents($space_key, $block_key, $accesslevel_key) {

	 
		global $CONN, $CONFIG;
		
		$component_list=false;
		$userlevel_key		  = $_SESSION['userlevel_key'];
		$current_user_key	   = $_SESSION['current_user_key'];
	
		if ($_SESSION['userlevel_key']!=1 && $accesslevel_key!=1 && $accesslevel_key!=3) {
			$sql = "select {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey,{$CONFIG['DB_PREFIX']}Modules.ModuleKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey,{$CONFIG['DB_PREFIX']}Modules.Name, {$CONFIG['DB_PREFIX']}ModuleTypes.Code, {$CONFIG['DB_PREFIX']}ModuleTypes.Image, {$CONFIG['DB_PREFIX']}Modules.Description,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ParentKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.Target,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.LinkKey,  {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.OwnerKey, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.EditRightsKey, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SortOrder, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.IconKey FROM {$CONFIG['DB_PREFIX']}Modules, {$CONFIG['DB_PREFIX']}ModuleTypes, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks where {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey AND {$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' and {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ParentKey='0' AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1' AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.BlockKey='$block_key') order by SortOrder, {$CONFIG['DB_PREFIX']}Modules.Name";
		
		} else {

			$sql = "select {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey,{$CONFIG['DB_PREFIX']}Modules.ModuleKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey,{$CONFIG['DB_PREFIX']}Modules.Name, {$CONFIG['DB_PREFIX']}ModuleTypes.Code, {$CONFIG['DB_PREFIX']}ModuleTypes.Image, {$CONFIG['DB_PREFIX']}Modules.Description,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ParentKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.Target,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.LinkKey, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.EditRightsKey, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.OwnerKey, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SortOrder, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.IconKey FROM {$CONFIG['DB_PREFIX']}Modules, {$CONFIG['DB_PREFIX']}ModuleTypes, {$CONFIG['DB_PREFIX']}ModuleSpaceLinks where {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey AND {$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' and {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ParentKey='0' and ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1' OR {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='3' OR {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='2') AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey!='4' AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.BlockKey='$block_key') order by SortOrder, {$CONFIG['DB_PREFIX']}Modules.Name";
  
		}

		$rs = $CONN->Execute("$sql");

		while (!$rs->EOF) {

			$icon_tag = ''; 
			$module_type_key = $rs->fields[0];
			$module_key2 = $rs->fields[1];
			$group_key2 = $rs->fields[2];
		
			//find out if group is visible or not
			if ($module_type_key==6) {
		
				if (!class_exists(InteractGroup)) {
			
					require_once($CONFIG['BASE_PATH'].'/modules/group/lib.inc.php');
				
				}
			
				if (!is_object($groupObject)) {
			
					$groupObject = new InteractGroup();
			
				}
				
				$group_data = $groupObject->getGroupData($module_key2);
					
			}
		
			if ($module_type_key!=6 || $userlevel_key==1 || $accesslevel_key==1 || $accesslevel_key==3 || in_array($module_key2,$group_access) || $group_data['visibility_key']==1) {

			
				$nav_name = $rs->fields[3];
				$nav_code = $rs->fields[4];
				$nav_image = $rs->fields[4];
				$nav_description = strip_tags(substr($rs->fields[6],0,255));
				$target = $rs->fields[8];
				$status_key = $rs->fields[9];
				$link_key2 = $rs->fields[10];
				$owner_key = $rs->fields[11];
				$edit_rights_key = $rs->fields[12];
				$sort_order = $rs->fields[13];						
				$nav_admin = $nav_code."_input.php";
				$icon_key = $rs->fields[14];
			
				if ($icon_key>2) {
			
					if (!class_exists('InteractHtml')) {
			
						require_once($CONFIG['BASE_PATH'].'/includes/lib/html.inc.php');
				
					}
			
					if (!is_object($htmlObject)) {
			
						$htmlObject = new InteractHtml();
			
					}
				
					$icon_tag = $htmlObject->getIconUrl($icon_key, 'small');	
			
				}
			
				if (isset($icon_tag) && $icon_tag!=false) {
			
					$nav_image = "$icon_tag";
				
				} else if ($icon_key==1){
			
					$nav_image = "{$CONFIG['PATH']}/images/$nav_image.gif";
			
				} else if ($icon_key==2){
			
					$nav_image = '';
			
				}
				// if user has admin rights show edit image
				$can_edit_link = check_link_edit_rights($link_key2,$accesslevel_key,$group_accesslevel,$owner_key,$edit_rights_key);
			
				if ($can_edit_link==true) {
					
					$admin_image=get_admin_tool("{$CONFIG['PATH']}/modules/$nav_code/$nav_admin?space_key=$space_key&amp;module_key=$module_key2&amp;link_key=$link_key2&amp;action=modify",true,"edit {$general_strings['module_text']} $module_key2 - sort order $sort_order");
				
				} else { 
	 	
					$admin_image='';
				
				}
			
				if ($module_type_key=="10") {
				
					if ($header==true) {
				
						$link = "</ul></li><li ><b class=\"small\">$nav_name</b>$admin_image<ul>";
					} else {
				
						$link = "<li ><b class=\"small\">$nav_name</b>$admin_image<ul>";
					}
					$header=true;
					$component_list .= $link;
				
				} else {
				
					if ($link_key==$link_key2) {
					 if ($status_key==2) {
						 $link = "<li  style=\"list-style-image: url($nav_image)\"><b class=\"smallred\">$nav_name</b> <span class=\"smallred\">X</span>$admin_image</li>";
				 	} else {
						 $link = "<li  style=\"list-style-image: url($nav_image)\"><b class=\"smallred\">$nav_name</b>$admin_image</li>";
				 	}
				} else {
					
					if ($status_key==2) {
						
						$hidden = '<span class="smallred">X</span>';
						
					} else {
					
						$hidden = '';
						
					}

					if ($nav_code=='space') {
						
						$rs_space_key = $CONN->Execute("SELECT SpaceKey, ShortName, CombineNames FROM {$CONFIG['DB_PREFIX']}Spaces WHERE ModuleKey='$module_key2'");
						
						while (!$rs_space_key->EOF) {
						
							$space_key2 = $rs_space_key->fields[0];
							$short_name = $rs_space_key->fields[1];
							$combine_names = $rs_space_key->fields[2];
							$rs_space_key->MoveNext();
							
						}
						if ($short_name!='' && $combine_names=='1') {
							$nav_name = $short_name.' - '.$nav_name;
						}
						$rs_space_key->Close();
						
						$link = "<li   ><a  style=\"background-image: url($nav_image)\" href=\"{$CONFIG['PATH']}/spaces/space.php?space_key=$space_key2\"  class=\"navlinks\" title=\"$nav_description\" target=\"$target\">$nav_name</a>$hidden $admin_image</li>";
						
					} else {
					
						$link = "<li   ><a  style=\"background-image: url($nav_image)\" href=\"{$CONFIG['PATH']}/modules/$nav_code/$nav_code.php?space_key=$space_key&amp;module_key=$module_key2&amp;link_key=$link_key2&amp;group_key=$group_key2\"  class=\"navlinks\" title=\"$nav_description\" target=\"$target\">$nav_name</a>$hidden $admin_image</li>";
					
					}
		
				}
  
				$component_list .= $link;
			
			}

			
			
			
		}
		$rs->MoveNext();
	}
	if ($header==true) {

		$component_list .= "</ul></li>";
		
	}
	
	return $component_list;	
		
	}//end getBlockComponents

} //end InteractSpace class	
?>