<?php
// +----------------------------------------------------------------------+
// | This file is part of Interact.										  |
// |																	  | 
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation (version 2)							  |
// |																	  | 
// | This program is distributed in the hope that it will be useful, but  |
// | WITHOUT ANY WARRANTY; without even the implied warranty of			  |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU	  |
// | General Public License for more details.							  |
// |																	  | 
// | You should have received a copy of the GNU General Public License	  |
// | along with this program; if not, you can view it at				  |
// | http://www.opensource.org/licenses/gpl-license.php					  |
// |																	  |
// +----------------------------------------------------------------------+
/**
* Space homepage
*
* Displays a space home page with header, news items, and if 
* the space contains a calendar, a list of important dates for the month
*
* @package Spaces
* @author Glen Davies <glen.davies@cce.ac.nz>
* @copyright Christchurch College of Education 2001 
* @version $Id: space.php,v 1.61 2006/03/10 02:52:12 glendavies Exp $
* 
*/

/**
* Include main system config file 
*/
require_once('../local/config.inc.php');

if (isset($_POST['show_new']) && $_POST['show_new']!=0) {
	$show_new = $_POST['show_new'];
	$last_use_seconds = $_POST['show_new']*86400;
	$last_use = date('Y-m-d H:i:s',time()-$last_use_seconds);

//if they have not logged in before set their last login to today

} else if ($_SESSION['last_use']>0) {

	$last_use = $_SESSION['last_use'];
	
} else {

	$last_use = date('Y-m-d H:i:s');
	
}

$current_user_key = $_SESSION['current_user_key'];
//get language strings

require_once($CONFIG['LANGUAGE_CPATH'].'/space_strings.inc.php');

$space_key 	= $_GET['space_key'];
$message = isset($_GET['message'])?$_GET['message']:'';
//check we have the required variables
check_variables(true,false);
	
if (!$space_key) {

	$space_key = $_SESSION['current_space_key'];
	
} else if ($space_key!=$_SESSION['current_space_key']){

	$_SESSION['current_space_key'] = $space_key;

}

//check to see if user is logged in. If not refer to Login page.
$access_levels = authenticate();
$accesslevel_key = isset($access_levels['accesslevel_key'])?$access_levels['accesslevel_key']:'';
$group_access = $access_levels['groups']; 
statistics('read');   
if (!isset($objSpace)) {
	if (!class_exists('InteractSpace')) {
		require_once('lib.inc.php');
	}
	$objSpace = new InteractSpace();				
}
if (!isset($objHtml)) {
	if (!class_exists('InteractHtml')) {
		require_once('../includes/lib/html.inc.php');
	}
	$objHtml = new InteractHtml();				
}			

require_once($CONFIG['TEMPLATE_CLASS_PATH'].'/template.inc');
$t = new Template($CONFIG['TEMPLATES_PATH']);  
$t->set_file(array(
	'header'		  => 'Header.ihtml',
	'navigation'	  => 'Navigation.ihtml',
	'body'			=> 'spaces/Home.ihtml',
	'event_table'	 => 'spaces/EventTable.ihtml',
	'footer'		  => 'Footer.ihtml'
));

$page_details=get_page_details($space_key);
set_common_template_vars($space_key,$module_key,$page_details, $message, $accesslevel_key, $group_accesslevel);
//get space home hit count
$hit_count = $CONN->GetOne("SELECT Count(SpaceKey) FROM {$CONFIG['DB_PREFIX']}Statistics WHERE SpaceKey='$space_key' AND ModuleKey='0'");
$t->set_var('PAGE_HITS',"<br>Page views - $hit_count");
//count number of users online

if ($space_key==$CONFIG['DEFAULT_SPACE_KEY']) {
	$rs = $CONN->Execute("SELECT DISTINCT user_key FROM {$CONFIG['DB_PREFIX']}online_users WHERE user_key!='0' AND  status_key=1");
	$rs_guests = $CONN->Execute("SELECT user_key FROM {$CONFIG['DB_PREFIX']}online_users WHERE user_key='0' OR  status_key=0");
	$guest_count = '<br />Guests: '.$rs_guests->RecordCount();
} else {
	$rs = $CONN->Execute("SELECT DISTINCT user_key FROM {$CONFIG['DB_PREFIX']}online_users, {$CONFIG['DB_PREFIX']}SpaceUserLinks WHERE {$CONFIG['DB_PREFIX']}online_users.user_key={$CONFIG['DB_PREFIX']}SpaceUserLinks.UserKey AND {$CONFIG['DB_PREFIX']}SpaceUserLinks.SpaceKey='$space_key' AND user_key!='0' AND {$CONFIG['DB_PREFIX']}online_users.status_key=1 ORDER BY time DESC");
}
if ($rs->RecordCount()==0 || !isset($_SESSION['current_user_key']) || $_SESSION['current_user_key']==0) {
	$member_count = $rs->RecordCount();	
} else {
	$member_count = '<a href="members.php?space_key='.$space_key.'&online_only=1">'.$rs->RecordCount().'</a>';
}
$t->set_var('USERS_ONLINE',$space_strings['members_online'].': '.$member_count.$guest_count);


$rs->Close();
if ($page_details['type_key']==1) {
	$t->set_block('body', 'UpdatesBlock', 'UpdtsBlock');
	$t->set_var('UpdtsBlock','');	
} else {
	//create dropdown to select days of new items to show
	$show_new_menu = $objHtml->arrayToMenu(array('0' => $general_strings['since_last_login'], '1' => $general_strings['today'], '3' => sprintf($general_strings['for_last_days'],3), '7' => sprintf($general_strings['for_last_days'],7), '30' => sprintf($general_strings['for_last_days'],30)),'show_new',$show_new,'','',true,'onchange="this.form.submit();"');
	$t->set_var('SHOW_NEW_MENU',$show_new_menu);
	$t->set_var('SHOW_NEW_ITEMS',$general_strings['show_new']);
}
//see if we have any new members, if so show new members links

if ($new_members>0) {

	$t->set_var('NEW_SPACE_MEMBERS_STRING','<a href="newmembers.php?space_key='.$space_key.'" class="small">('.sprintf($general_strings['new_postings_count'], $new_members).')</a>');	

} else {

	$t->set_block('navigation', 'NewMembersBlock', 'NMBlock');
	$t->set_var('NMBlock','');	

}

$space_header = $objHtml->parseText($page_details['header']);
if (!empty($_GET['first_login'])) {
	$space_header = '<div class="systemMessage">'.sprintf($general_strings['first_login'],$CONFIG['SERVER_NAME']).'</div>'.$space_header;
}

if ($_SESSION['userlevel_key']=='1' || $accesslevel_key=='1' || $accesslevel_key=='3') {
	if($page_details['header']=='') {
		$space_header = '<span'.get_admin_tool_class().'>'.$space_strings['space_welcome_prompt'].'</span>';
	}
	$edit_header = get_admin_tool('../spaceadmin/spaceheader.php?space_key='.$space_key,true);
}


$t->set_var('HEADER',$space_header);
$t->set_var('EDIT_HEADER',isset($edit_header)?$edit_header:'');
$t->parse('CONTENTS', 'header', true);
$t->set_var('LATEST_POSTINGS_STRING',$general_strings['latest_postings']);
$t->set_var('NEW_ITEMS_STRING',$general_strings['new_items']);
$t->set_var('UPDATED_ITEMS_STRING',$general_strings['updated_items']);
$t->set_var('SPACE_KEY',$space_key);

if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	
	$t->set_var('LATEST_ITEMS_STRING',sprintf($general_strings['all_latest_items'], $general_strings['space_plural']));
	
} else {

	$t->set_var('LATEST_ITEMS_STRING',sprintf($general_strings['space_latest_items'], $general_strings['space_text']));

}
$t->set_var('SUB_SPACES_STRING',sprintf($space_strings['sub_sites'], $general_strings['space_plural']));
$add_block_one = sprintf($space_strings['add_block_one'], $general_strings['module_text']);
get_navigation();
if ($_SESSION['userlevel_key']==1 || $accesslevel_key==1 || $accesslevel_key==3) {

	$t->set_var('ADD_BLOCK_ONE_LINK',get_admin_tool('../modules/general/moduleadd.php?space_key='.$space_key.'&block_key=1',true,$add_block_one,'plus'));
	
}

if (!class_exists('InteractDate')) {

	require_once('../includes/lib/date.inc.php');
	
}

$dates = new InteractDate();
// find out what groups and spaces user is a member of
if (!class_exists('InteractUser')) {

	require_once('../includes/lib/user.inc.php');
	
}

$user = new InteractUser();
$groups_data  = $user->getGroupsData($_SESSION['current_user_key'], $space_key);
$groups_sql   = $groups_data['groups_sql'];
$group_access = $groups_data['groups_array'];
$spaces_data  = $user->getSpacesData($_SESSION['current_user_key']);
$spaces_sql   = $spaces_data['spaces_sql'];

//if portfolio space remove updates panel

if ($_SESSION['userlevel_key']=='1' || $accesslevel_key=='1' || $accesslevel_key=='3' && $page_details['type_key']!=1) {

	$add_news_link = get_admin_tool('../news/newsinput.php?space_key='.$space_key,true,$space_strings['add_news'],'plus');
	$t->set_var('ADD_NEWS_LINK',$add_news_link);

}

//get any news items for this space

$t->set_block('body', 'NewsBlock', 'NWBlock');

if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	 
	if ($CONFIG['DISPLAY_LATEST']==0 || isset($_POST['last_use'])) {

		$date_limit = "AND {$CONFIG['DB_PREFIX']}News.DateAdded>'$last_use'";

	}
	
	$sql = "SELECT DISTINCT
		{$CONFIG['DB_PREFIX']}News.Heading,
		{$CONFIG['DB_PREFIX']}News.Body,
		{$CONFIG['DB_PREFIX']}News.DateAdded, 
		FirstName, LastName, 
		{$CONFIG['DB_PREFIX']}News.UserKey, 
		{$CONFIG['DB_PREFIX']}News.NewsKey, 
		{$CONFIG['DB_PREFIX']}Spaces.Name,
		{$CONFIG['DB_PREFIX']}News.SpaceKey 
		FROM 
		{$CONFIG['DB_PREFIX']}News, 
		{$CONFIG['DB_PREFIX']}Users, 
		{$CONFIG['DB_PREFIX']}Spaces 
		WHERE 
		{$CONFIG['DB_PREFIX']}News.UserKey={$CONFIG['DB_PREFIX']}Users.UserKey 
		AND 
		{$CONFIG['DB_PREFIX']}Spaces.SpaceKey={$CONFIG['DB_PREFIX']}News.SpaceKey
		AND 
		(({$CONFIG['DB_PREFIX']}News.SpaceKey IN $spaces_sql) 
		OR 
		 ({$CONFIG['DB_PREFIX']}News.SpaceKey='{$CONFIG['DEFAULT_SPACE_KEY']}')) $date_limit
		ORDER BY {$CONFIG['DB_PREFIX']}News.DateAdded DESC";
	
} else {

	if (isset($_POST['last_use'])) {
		$date_limit = "AND {$CONFIG['DB_PREFIX']}News.DateAdded>'$last_use'";
	}
	$sql = "SELECT {$CONFIG['DB_PREFIX']}News.Heading,{$CONFIG['DB_PREFIX']}News.Body,{$CONFIG['DB_PREFIX']}News.DateAdded, FirstName, LastName,  {$CONFIG['DB_PREFIX']}News.UserKey, {$CONFIG['DB_PREFIX']}News.NewsKey FROM {$CONFIG['DB_PREFIX']}News, {$CONFIG['DB_PREFIX']}Users  WHERE {$CONFIG['DB_PREFIX']}News.UserKey={$CONFIG['DB_PREFIX']}Users.UserKey AND {$CONFIG['DB_PREFIX']}News.SpaceKey='$space_key'  $date_limit ORDER BY {$CONFIG['DB_PREFIX']}News.DateAdded DESC";

}
$rs = $CONN->Execute($sql);

echo $CONN->ErrorMsg();
if (($rs->EOF && $_SESSION['userlevel_key']!='1' && $accesslevel_key!='1' && $accesslevel_key!='3') || $page_details['type_key']==1) {


	$t->set_block('body', 'NewsHeadingBlock', 'NWHBlock');
	$t->set_var('NWHBlock','');
	
} else {
	
	$t->set_var('NEWS_STRING',$general_strings['news']);
	$n=0;
	while (!$rs->EOF && $n<2) {

		$heading = $rs->fields[0];
		
		$body=$objHtml->parseText($rs->fields[1]);
		$date_added = $dates->formatDate($CONN->UnixTimeStamp($rs->fields[2]),'long');	
		$name = $rs->fields[3].' '.$rs->fields[4];
		$user_key = $rs->fields[5];
		$news_key = $rs->fields[6];
		$space_name = $rs->fields[7];
		$news_space_key = $rs->fields[8];
		$photo_tag = $user->getUserPhotoTag($user_key, '40');
	
		if ($photo_tag==false) {
	
			$photo_tag='&nbsp;';
	
		}
		if ($_SESSION['userlevel_key']=='1' || $accesslevel_key=='1' || $accesslevel_key=='3') {
            
	    	$admin_image=get_admin_tool("{$CONFIG['PATH']}/news/newsinput.php?space_key=$space_key&news_key=$news_key&action=modify");
        	$t->set_var('ADMIN_IMAGE',$admin_image);
        
		}
		$t->set_var('PHOTO_TAG',$photo_tag);
		$t->set_var('SPACE_HEADING',$space_name);
		$t->set_var('HEADING',$heading);
		$t->set_var('ADDED_BY',$name);
		$t->set_var('DATE_ADDED',$date_added);
		$t->set_var('BODY',$body);
		$t->set_var('NEWS_SPACE_KEY',$news_space_key);	
		$t->parse('NWBlock', 'NewsBlock', true);
		$n++;				
		$rs->MoveNext();
	}
	
}

if ($rs->RecordCount()<=2) {

	$t->set_block('body', 'MoreNewsBlock', 'MNBlock');
	$t->set_var('MNBlock','');

} else {

	$t->set_var('MORE_NEWS_STRING',$space_strings['more_news']);

}
$rs->Close();


if (!isset($_SESSION['current_user_key']) || $_SESSION['current_user_key']=='') {
	$t->set_block('body', 'UpdatesBlock', 'UDBlock');
	$t->set_var('UDBlock','');
}

//find out if there are any module in this space, if not don't display current item boxes and give prompt on ow to add content

$rs = $CONN->Execute("SELECT ModuleKey FROM {$CONFIG['DB_PREFIX']}ModuleSpaceLinks WHERE {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey!='4'");

if ($rs->EOF) {

	$t->set_block('body', 'UpdatesBlock', 'UDBlock');
	$t->set_var('UDBlock','');
	$t->set_var('SPACE_NAME','');
	if ($_SESSION['userlevel_key']=='1' || $accesslevel_key=='1' || $accesslevel_key=='3') {
		$t->set_var('MESSAGE',sprintf($space_strings['space_content_prompt'],$general_strings['space_text']));
	}

	
} else {

	$sql = "SELECT {$CONFIG['DB_PREFIX']}Modules.ModuleKey FROM {$CONFIG['DB_PREFIX']}Modules,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks WHERE ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' AND ModuleTypeKey='7') AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}Modules.ModuleKey AND {$CONFIG['DB_PREFIX']}Modules.StatusKey!='4') AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1' AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' OR {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql)";

	$rs = $CONN->Execute($sql);
	if (!$rs->EOF) {

		$n=0;
		$parent_array=array();
		$mods='';
		
		while (!$rs->EOF) {
			if ($mods) {$mods.=',';}
			$mods.="'{$rs->fields[0]}'";
			get_cal_parents($rs->fields[0]);
			while (list ($key, $val) = each ($parent_array)) {
		
				$mods .= ",'$val'"; 
			}
			$rs->MoveNext();
		}

		$rs->Close();
		
		$month=date('m');
		$year=date('Y');
	
		$sql = "SELECT EventKey, EventDate,Name, ModuleKey FROM {$CONFIG['DB_PREFIX']}CalendarEvents WHERE (ModuleKey in ($mods)) AND EventDate >= CURDATE() AND EventDate <= DATE_ADD(CURRENT_DATE, INTERVAL 30 DAY) ORDER BY EventDate";
	
		$rs = $CONN->Execute($sql);
	
		//set event_key1 variable so we can eliminate duplicates caused by Calendars linked in more than one group
//		$event_key1='';
	
		$t->set_var('IMPORTANT_DATES_STRING',$space_strings['important_dates']);
	
		if ($rs->EOF) {
	
			$events=$space_strings['no_events'];
	
		} else {
	
			while (!$rs->EOF) {
		
				$event_key = $rs->fields[0];
				$event_date = $dates->formatDate($CONN->UnixTimeStamp($rs->fields[1]),'short');
				$name = $rs->fields[2];
				$module_key2 = $rs->fields[3];
//				$group_key = $rs->fields[4];
//				if (($group_key==0 | in_array($group_key,$group_access )) && $event_key!=$event_key1) {
			
					$events = $events."<a href=\"../modules/calendar/event.php?space_key=$space_key&amp;module_key=$module_key2&amp;event_key=$event_key\" >$event_date</a> - $name<br /><br />";
				
//				}
//				$event_key1=$event_key;
				$rs->MoveNext();
			
			}
		
			$rs->Close();
		
		}
	
		$t->set_var('EVENTS',$events);
		$t->parse('EVENT_TABLE', 'event_table', true);
	
	}
	
	//now count new postings
	if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	
		$sql = "SELECT DISTINCT {$CONFIG['DB_PREFIX']}posts.post_key FROM  {$CONFIG['DB_PREFIX']}ModuleSpaceLinks,{$CONFIG['DB_PREFIX']}SpaceUserLinks, {$CONFIG['DB_PREFIX']}posts, {$CONFIG['DB_PREFIX']}Modules WHERE {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey={$CONFIG['DB_PREFIX']}SpaceUserLinks.SpaceKey AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}posts.module_key AND {$CONFIG['DB_PREFIX']}posts.module_key={$CONFIG['DB_PREFIX']}Modules.ModuleKey AND ({$CONFIG['DB_PREFIX']}SpaceUserLinks.UserKey='$current_user_key') AND ({$CONFIG['DB_PREFIX']}posts.date_added >= '$last_use') AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' OR {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1' AND {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='14'";
	
		
	} else {

		$sql = "SELECT DISTINCT {$CONFIG['DB_PREFIX']}posts.post_key FROM  {$CONFIG['DB_PREFIX']}ModuleSpaceLinks, {$CONFIG['DB_PREFIX']}posts, {$CONFIG['DB_PREFIX']}Modules WHERE  {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}posts.module_key AND {$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}posts.module_key AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key') AND ({$CONFIG['DB_PREFIX']}posts.date_added >= '$last_use') AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' OR {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1' AND {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='14'";

	}
	
	$rs = $CONN->Execute($sql);
	echo $CONN->ErrorMsg();
	$record_count=$rs->RecordCount();

	if ($record_count>0) {

		$new_post_count = '<a href="newposts.php?space_key='.$space_key.'" class="small">'.sprintf($general_strings['new_postings_count'], $record_count).'</a>';

	} else {

		$new_post_count = sprintf($general_strings['new_postings_count'], $record_count);

	}

	$t->set_var('NEW_POST_COUNT',$new_post_count);
	
	if ($CONFIG['DISPLAY_LATEST']==0 || isset($_POST['last_use'])) {

		$date_limit = "AND {$CONFIG['DB_PREFIX']}posts.date_added>'$last_use'";

	}
	if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	
		$sql = "SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}posts.post_key, 
		subject, 
		thread_key, 
		{$CONFIG['DB_PREFIX']}posts.module_key, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code,
		{$CONFIG['DB_PREFIX']}posts.entry_key 
		FROM  
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks,
		{$CONFIG['DB_PREFIX']}SpaceUserLinks, 
		{$CONFIG['DB_PREFIX']}posts,
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}Modules 
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey
		AND
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey={$CONFIG['DB_PREFIX']}SpaceUserLinks.SpaceKey 
		AND 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}posts.module_key 
		AND 
		({$CONFIG['DB_PREFIX']}SpaceUserLinks.UserKey='$current_user_key') 
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey IN $groups_sql)
		AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1'
		AND {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='14' 
		$date_limit
		ORDER BY 
		{$CONFIG['DB_PREFIX']}posts.date_added DESC";
		
	} else {	
	
		//now retrieve latest 5 forum postings

		$sql = "SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}posts.post_key, 
		subject, 
		thread_key, 
		{$CONFIG['DB_PREFIX']}posts.module_key, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code,
		{$CONFIG['DB_PREFIX']}posts.entry_key
		FROM  
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks,
		{$CONFIG['DB_PREFIX']}posts,
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}Modules
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleKey={$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey
		AND
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}posts.module_key 
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key') 
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey IN $groups_sql) 
		AND 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1'
		 AND {$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='14'
		$date_limit
		ORDER BY 
		{$CONFIG['DB_PREFIX']}posts.date_added DESC";

	}
	
	$rs = $CONN->SelectLimit($sql,5);

	$n=0;

	if (!$rs->EOF) {

		$t->set_block('body', 'NewPostBlock', 'NPBlock');
	
		while (!$rs->EOF) {
	
			$t->set_var('POST_KEY',$rs->fields[0]);
			$t->set_var('SUBJECT',$rs->fields[1]);
			$t->set_var('THREAD_KEY',$rs->fields[2]);
			$t->set_var('MODULE_KEY',$rs->fields[3]);
			$t->set_var('FORUM_SPACE_KEY',$rs->fields[4]);
			$t->set_var('ENTRY_KEY',$rs->fields[6]);
			
			if ($rs->fields[5]=='forum') {
			
				$t->set_var('POST_URL','forum/thread.php');
			
			} else {
			
				$t->set_var('POST_URL', $rs->fields[5].'/entry.php');
			
			}						
			$t->parse('NPBlock', 'NewPostBlock', true);
			$n++;
			$rs->MoveNext();
	
		}
	
		if ($n==5 && $record_count>5) {
	
			$t->set_var('MORE_POSTS_LINK','<div align="right"><a href="newposts.php" class="small">...'.$general_strings['more'].'</a></div>');
	
		}

	} else {

		$t->set_block('body', 'NewPostsBlock', 'NPSBlock');
		$t->set_var('NPSBlock','');

	}

	//now get any new items
	if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) { 
	
		$sql = "
		SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey, 
		{$CONFIG['DB_PREFIX']}Modules.Name,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code
		FROM  
		{$CONFIG['DB_PREFIX']}Modules, 
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks,
		{$CONFIG['DB_PREFIX']}SpaceUserLinks 
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey={$CONFIG['DB_PREFIX']}SpaceUserLinks.SpaceKey 
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}Modules.ModuleKey 
		AND 
		({$CONFIG['DB_PREFIX']}SpaceUserLinks.UserKey='$current_user_key')
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) 	 
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1')
		AND
		({$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='10')
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded >= '$last_use')
		ORDER BY 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded DESC";

	} else {
	
		$sql = "
		SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey, 
		{$CONFIG['DB_PREFIX']}Modules.Name,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code
		FROM  
		{$CONFIG['DB_PREFIX']}Modules, 
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}Modules.ModuleKey 
		AND 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' 
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) 	 
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1')
		AND
		({$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='10')
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded >= '$last_use')
		ORDER BY 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded DESC";

	}
	$rs = $CONN->Execute($sql);

	$record_count=$rs->RecordCount();

	if ($record_count>0) {

		$new_items_count = '<a href="newitems.php?space_key='.$space_key.'" class="small">'.sprintf($general_strings['new_postings_count'], $record_count).'</a>';

	} else {

		$new_items_count = sprintf($general_strings['new_postings_count'], $record_count);

	}		
	$t->set_var('NEW_ITEMS_COUNT',$new_items_count);

	if ($CONFIG['DISPLAY_LATEST']==0 || isset($_POST['last_use'])) {

		$date_limit = "AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded>'$last_use'";

	}
	if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	
		$sql = "
		SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey, 
		{$CONFIG['DB_PREFIX']}Modules.Name,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code
		FROM  
		{$CONFIG['DB_PREFIX']}Modules, 
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks,
		{$CONFIG['DB_PREFIX']}SpaceUserLinks 
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey={$CONFIG['DB_PREFIX']}SpaceUserLinks.SpaceKey 
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}Modules.ModuleKey 
		AND 
		({$CONFIG['DB_PREFIX']}SpaceUserLinks.UserKey='$current_user_key')
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) 	 
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1')
		AND
		({$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='10')
		$date_limit
		ORDER BY 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded DESC";
	
	} else {
	
		$sql = "
		SELECT DISTINCT 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey, 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey, 
		{$CONFIG['DB_PREFIX']}Modules.Name,
		{$CONFIG['DB_PREFIX']}ModuleTypes.Code
		FROM  
		{$CONFIG['DB_PREFIX']}Modules, 
		{$CONFIG['DB_PREFIX']}ModuleTypes,
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks
		WHERE 
		{$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey={$CONFIG['DB_PREFIX']}ModuleTypes.ModuleTypeKey
		AND
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey={$CONFIG['DB_PREFIX']}Modules.ModuleKey 
		AND 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.SpaceKey='$space_key' 
		AND 
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey='0' 
		OR 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.GroupKey in $groups_sql) 	 
		AND
		({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1')
		AND
		({$CONFIG['DB_PREFIX']}Modules.ModuleTypeKey!='10')
		$date_limit
		ORDER BY 
		{$CONFIG['DB_PREFIX']}ModuleSpaceLinks.DateAdded DESC";
	}
	
	$rs = $CONN->SelectLimit($sql,5);

	$n=0;

	if (!$rs->EOF) {

		$t->set_block('body', 'NewItemBlock', 'NIBlock');

		while (!$rs->EOF) {
		
			$t->set_var('MODULE_KEY', $rs->fields[0]);
			$t->set_var('ITEM_SPACE_KEY', $rs->fields[1]);
			$t->set_var('NAME', $rs->fields[2]);
			$t->set_var('CODE', $rs->fields[3]);			
			$t->parse('NIBlock', 'NewItemBlock', true);	  
			$n++;		
			$rs->MoveNext();
		
		}
	
		if ($n==5 && $record_count>5) {
	
			$t->set_var('MORE_ITEMS_LINK','<div align="right"><a href="newitems.php?space_key='.$space_key.'" class="small">...'.$general_strings['more'].'</a></div>');
	
		}	
	
		$rs->Close();

	} else {

		$t->set_block('body', 'NewItemsBlock', 'NISBlock');
		$t->set_var('NISBlock','');	

	}

	//now run through modules and get any updated items

	require_once($CONFIG['LANGUAGE_CPATH'].'/module_strings.inc.php');
	
	if ($space_key == $CONFIG['DEFAULT_SPACE_KEY']) {
	
		$updates_space_key='';
	
	} else {
	
		$updates_space_key=$space_key;
	
	}
	
	$rs = $CONN->Execute("SELECT Code From {$CONFIG['DB_PREFIX']}ModuleTypes");

	while (!$rs->EOF) {

		$code		= $rs->fields[0];
		$module_file = $CONFIG['BASE_PATH'].'/modules/'.$code.'/'.$code.'.inc.php';
	
		if (file_exists($module_file)) {
	
			include_once($module_file);
			$updated_items_function = 'updated_items_'.$code;
	   
			if (function_exists($updated_items_function)) {
		
				
				if (!$updated_items_function($current_user_key, $last_use, $groups_sql, $updated_items, $module_strings, $updates_space_key)) {
			
					echo "Error: could not run updated items functions for  $code\n";
						
				}
		
			}
		}
	
		$rs->MoveNext();
	
	}
	if (!isset($updated_items) || $updated_items=='') {

		$t->set_var('UPDATED_ITEMS','<span class="small">'.$general_strings['no_item_updates'].'</span>');	 

	} else {

		$t->set_var('UPDATED_ITEMS',$updated_items);	 
	
	}

	$n=0;
	while (!$rs->EOF) {
		
		$t->set_var('MODULE_KEY', $rs->fields[0]);
		$t->set_var('UPDATED_SPACE_KEY', $rs->fields[1]);
		$t->set_var('NAME', $rs->fields[2]);
		$t->set_var('CODE', $rs->fields[3]);			
		$t->parse('NIBlock', 'NewItemsBlock', true);	  
		$n++;		
		$rs->MoveNext();
		
	}
	if ($n==5 && $record_count>5) {
	
		 $t->set_var('MORE_ITEMS_LINK','<div align="right"><a href="newitems.php" class="small">...'.$general_strings['more'].'</a></div>');
	
	}	

	$rs->Close();

}

$block_one_components = $objSpace->getBlockComponents($space_key, 1,$accesslevel_key);
if (($block_one_components==false && ($_SESSION['userlevel_key']!=1 && $accesslevel_key!=1 && $accesslevel_key!=3)) || $page_details['type_key']==1) {

	$t->set_block('body', 'BlockOneBlock', 'BOneBlock');
	$t->set_var('BOneBlock','');	

} else {

	$t->set_var('BLOCK_ONE_COMPONENTS',$block_one_components);
		
}


	
$t->set_var('OTHER_SPACES',$spaces);
$t->parse('CONTENTS', 'body', true);
$date_modified = get_date_space_modified($space_key);
$t->set_var('DATE_MODIFIED_INFO', sprintf($space_strings['last_modified'],$general_strings['space_text'], $date_modified));
$t->parse('CONTENTS', 'footer', true);
print_headers();
$t->p("CONTENTS");

$CONN->Close();
exit;

function get_cal_parents($cal_key) 
{
	global $CONN,$n,$parent_array, $CONFIG;

	$sql = "SELECT ParentCalendarKey from {$CONFIG['DB_PREFIX']}Calendars,{$CONFIG['DB_PREFIX']}Modules,{$CONFIG['DB_PREFIX']}ModuleSpaceLinks where {$CONFIG['DB_PREFIX']}Calendars.ModuleKey='$cal_key' AND ({$CONFIG['DB_PREFIX']}Modules.ModuleKey=ParentCalendarKey AND {$CONFIG['DB_PREFIX']}Modules.StatusKey!='4') AND ({$CONFIG['DB_PREFIX']}ModuleSpaceLinks.ModuleKey=ParentCalendarKey AND {$CONFIG['DB_PREFIX']}ModuleSpaceLinks.StatusKey='1')";
	$rs = $CONN->Execute($sql);

	while (!$rs->EOF) {
		$parent_cal_key = $rs->fields[0];
		$rs->Close();
		if ($parent_cal_key==0 || in_array($parent_cal_key,$parent_array)) {
			return;
		} else {
			$parent_array[$n++]= $parent_cal_key;
			get_cal_parents($parent_cal_key);
		}
		$rs->MoveNext();
	}
} //end get_cal_parents

?>